#nullable enable
using Canon.Core.Abstractions;
using Canon.Core.GrammarParser;
using Canon.Core.Enums;
namespace Canon.Tests.GeneratedParserTests;

public class GeneratedTransformer : ITransformer
{
    private IDictionary<TerminatorBase, string> _shiftPointers;

    public string Name { get; }

    public IDictionary<Terminator, ReduceInformation> ReduceTable { get; }

    public IDictionary<TerminatorBase, ITransformer> ShiftTable { get; }

    public GeneratedTransformer(Dictionary<TerminatorBase, string> shiftTable,
        Dictionary<Terminator, ReduceInformation> reduceTable, string name)
    {
        ReduceTable = reduceTable;
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = shiftTable;
        Name = name;
    }

    public GeneratedTransformer()
    {
        ReduceTable = new Dictionary<Terminator, ReduceInformation>();
        ShiftTable = new Dictionary<TerminatorBase, ITransformer>();
        _shiftPointers = new Dictionary<TerminatorBase, string>();
        Name = Guid.NewGuid().ToString();
    }

    public void ConstructShiftTable(Dictionary<string, GeneratedTransformer> transformers)
    {
        foreach (KeyValuePair<TerminatorBase,string> pair in _shiftPointers)
        {
            ShiftTable.Add(pair.Key, transformers[pair.Value]);
        }
    }

    public override bool Equals(object? obj)
    {
        if (obj is not GeneratedTransformer other)
        {
            return false;
        }

        return Name == other.Name;
    }

    public override int GetHashCode() => Name.GetHashCode();
}
public class GeneratedGrammarParser : IGrammarParser
{
	private static readonly Dictionary<string, GeneratedTransformer> s_transformers = new()
	{
		{ "28c8b345-5ba6-40c1-93f1-1e6c1fa1400b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramStruct), "8a33f85a-3666-48f2-a662-93757908ca68"}, { new NonTerminator(NonTerminatorType.ProgramHead), "9faed86d-ac16-4f8a-887c-aa83a93d143c"}, { new Terminator(KeywordType.Program), "252a3754-1cbd-4e58-af0d-cff50c5c5f8d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "28c8b345-5ba6-40c1-93f1-1e6c1fa1400b") },
		{ "8a33f85a-3666-48f2-a662-93757908ca68", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.StartNonTerminator))}, }, "8a33f85a-3666-48f2-a662-93757908ca68") },
		{ "9faed86d-ac16-4f8a-887c-aa83a93d143c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "5a3d3b83-1f80-40cb-88eb-0fd68ccf9881"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9faed86d-ac16-4f8a-887c-aa83a93d143c") },
		{ "252a3754-1cbd-4e58-af0d-cff50c5c5f8d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "10ebfb40-7ed4-4c79-81c2-069d635a89f2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "252a3754-1cbd-4e58-af0d-cff50c5c5f8d") },
		{ "5a3d3b83-1f80-40cb-88eb-0fd68ccf9881", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ProgramBody), "f09637e1-955c-4ce5-8220-a12b1c4686ba"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "604d5d41-e408-4b55-a243-ecc2aeae9e37"}, { new Terminator(KeywordType.Const), "7116fc9f-7dd5-4b9e-9995-0a3d24ed7b56"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "5a3d3b83-1f80-40cb-88eb-0fd68ccf9881") },
		{ "10ebfb40-7ed4-4c79-81c2-069d635a89f2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "7c43e864-2a5f-4ed7-b41a-8a2f962ed948"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "10ebfb40-7ed4-4c79-81c2-069d635a89f2") },
		{ "f09637e1-955c-4ce5-8220-a12b1c4686ba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Period), "5efadaca-3a3e-4a1e-a1c3-701ee0c2627f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f09637e1-955c-4ce5-8220-a12b1c4686ba") },
		{ "604d5d41-e408-4b55-a243-ecc2aeae9e37", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "7a91c5f9-40d6-43ab-a2d9-d4957607cdde"}, { new Terminator(KeywordType.Var), "926c4c53-ec6c-409f-96a7-29807e9b065a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "604d5d41-e408-4b55-a243-ecc2aeae9e37") },
		{ "7116fc9f-7dd5-4b9e-9995-0a3d24ed7b56", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstDeclaration), "a94092de-54d6-47d0-98a2-414f4d04e059"}, { Terminator.IdentifierTerminator, "ab422310-23bc-4844-8f89-e829eafb3d4a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7116fc9f-7dd5-4b9e-9995-0a3d24ed7b56") },
		{ "7c43e864-2a5f-4ed7-b41a-8a2f962ed948", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "ee6d64b7-116e-480e-b062-84a50fea7ccf"}, { Terminator.IdentifierTerminator, "91c7eb8e-958e-4097-929e-bed2afc2350f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7c43e864-2a5f-4ed7-b41a-8a2f962ed948") },
		{ "5efadaca-3a3e-4a1e-a1c3-701ee0c2627f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.EndTerminator, new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramStruct))}, }, "5efadaca-3a3e-4a1e-a1c3-701ee0c2627f") },
		{ "7a91c5f9-40d6-43ab-a2d9-d4957607cdde", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramDeclarations), "e536ba5c-48be-43e2-a14f-f9ecd11ad077"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(0, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "7a91c5f9-40d6-43ab-a2d9-d4957607cdde") },
		{ "926c4c53-ec6c-409f-96a7-29807e9b065a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclaration), "a1cc676f-b66d-4643-a72f-032f013e555a"}, { new NonTerminator(NonTerminatorType.IdentifierList), "d46d46d6-6704-4456-bb53-63e00b964e11"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "926c4c53-ec6c-409f-96a7-29807e9b065a") },
		{ "a94092de-54d6-47d0-98a2-414f4d04e059", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "af6de59a-abf3-4102-889f-d7850f6b7969"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a94092de-54d6-47d0-98a2-414f4d04e059") },
		{ "ab422310-23bc-4844-8f89-e829eafb3d4a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "a7d3d68b-5a81-487c-91d4-4c8c2e93bd05"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ab422310-23bc-4844-8f89-e829eafb3d4a") },
		{ "ee6d64b7-116e-480e-b062-84a50fea7ccf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a3754b0e-9be9-4f6d-b38d-2a5eb876dff6"}, { new Terminator(DelimiterType.Comma), "a603fd63-23aa-4511-9644-d785f3316308"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ee6d64b7-116e-480e-b062-84a50fea7ccf") },
		{ "91c7eb8e-958e-4097-929e-bed2afc2350f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "91c7eb8e-958e-4097-929e-bed2afc2350f") },
		{ "e536ba5c-48be-43e2-a14f-f9ecd11ad077", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "200a4dfc-cbe5-4caa-bc2a-f4bebf6441a8"}, { new Terminator(KeywordType.Begin), "2fdf39fe-523f-4296-b55a-2c42a395f4c7"}, { new NonTerminator(NonTerminatorType.Subprogram), "48ee6372-24f9-4468-bccf-0da315669fa3"}, { new NonTerminator(NonTerminatorType.SubprogramHead), "39afebcb-834f-4927-8741-5511aa02bd4c"}, { new Terminator(KeywordType.Procedure), "ba615436-6719-4845-919e-db11ac3e2147"}, { new Terminator(KeywordType.Function), "608562d7-003d-4403-99d3-37a368581ff9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e536ba5c-48be-43e2-a14f-f9ecd11ad077") },
		{ "a1cc676f-b66d-4643-a72f-032f013e555a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "30645ad8-0e1e-4898-8c33-42ee7acb443f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a1cc676f-b66d-4643-a72f-032f013e555a") },
		{ "d46d46d6-6704-4456-bb53-63e00b964e11", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "6bfd4ef9-56ca-45b8-a8d2-9d15d12304a1"}, { new Terminator(DelimiterType.Comma), "ae5b7951-95cd-43aa-9b36-65de906882e0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d46d46d6-6704-4456-bb53-63e00b964e11") },
		{ "69243085-a468-4c2a-8573-e0df8d82054f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "69243085-a468-4c2a-8573-e0df8d82054f") },
		{ "af6de59a-abf3-4102-889f-d7850f6b7969", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "93d7c9f5-c066-4e60-b633-5be0ef2807b8"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "af6de59a-abf3-4102-889f-d7850f6b7969") },
		{ "a7d3d68b-5a81-487c-91d4-4c8c2e93bd05", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "912e4da1-e8fb-4a38-8030-e12208663cc8"}, { new Terminator(OperatorType.Plus), "781c1c65-aace-4a9f-99a0-27db800d49de"}, { new Terminator(OperatorType.Minus), "b8fcf909-531f-4031-9b0d-6918b017877b"}, { Terminator.NumberTerminator, "7cfe0e9a-5fa8-4b51-a756-42ba64deebce"}, { Terminator.CharacterTerminator, "614f21e7-00f7-4874-bbcd-27b78c54917a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a7d3d68b-5a81-487c-91d4-4c8c2e93bd05") },
		{ "a3754b0e-9be9-4f6d-b38d-2a5eb876dff6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ProgramHead))}, }, "a3754b0e-9be9-4f6d-b38d-2a5eb876dff6") },
		{ "a603fd63-23aa-4511-9644-d785f3316308", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "c8bd17aa-2a90-4757-ae25-ea4598ab61dd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a603fd63-23aa-4511-9644-d785f3316308") },
		{ "200a4dfc-cbe5-4caa-bc2a-f4bebf6441a8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProgramBody))}, }, "200a4dfc-cbe5-4caa-bc2a-f4bebf6441a8") },
		{ "2fdf39fe-523f-4296-b55a-2c42a395f4c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "690bea35-3943-4411-8844-cc7656fc6ba3"}, { new NonTerminator(NonTerminatorType.Statement), "fdd837f2-ea2b-4b7d-b508-9ae3784e8527"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "2fdf39fe-523f-4296-b55a-2c42a395f4c7") },
		{ "48ee6372-24f9-4468-bccf-0da315669fa3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "706956c0-39db-4fb3-a8e8-bd30d7971735"},}, new Dictionary<Terminator, ReduceInformation>{ }, "48ee6372-24f9-4468-bccf-0da315669fa3") },
		{ "39afebcb-834f-4927-8741-5511aa02bd4c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Semicolon), "b0d7660b-c146-4468-8e49-95f98e057cb3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "39afebcb-834f-4927-8741-5511aa02bd4c") },
		{ "ba615436-6719-4845-919e-db11ac3e2147", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "72b7ac1c-9458-4b3b-9ef4-6c4e896b3b04"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ba615436-6719-4845-919e-db11ac3e2147") },
		{ "608562d7-003d-4403-99d3-37a368581ff9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "608a01ce-ac56-4141-89f7-d7177e0fd7d1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "608562d7-003d-4403-99d3-37a368581ff9") },
		{ "30645ad8-0e1e-4898-8c33-42ee7acb443f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.IdentifierList), "f85556a6-d6d4-4cfb-a5f2-5e1b809e273c"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "30645ad8-0e1e-4898-8c33-42ee7acb443f") },
		{ "6bfd4ef9-56ca-45b8-a8d2-9d15d12304a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "9e325725-9124-465d-b265-b7e686bfefb8"}, { new NonTerminator(NonTerminatorType.BasicType), "4813c436-65fe-414d-bf37-063661cce00d"}, { new Terminator(KeywordType.Array), "dc6b04bc-1024-4c2b-9e7e-cb431d368490"}, { new Terminator(KeywordType.Integer), "af867cb8-3fd0-40d2-93ed-821588536cd6"}, { new Terminator(KeywordType.Real), "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498"}, { new Terminator(KeywordType.Boolean), "e7f508c2-f944-4a52-82c9-2c1da660b58e"}, { new Terminator(KeywordType.Character), "50dac50a-0c16-462e-934c-bcce04c19b99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6bfd4ef9-56ca-45b8-a8d2-9d15d12304a1") },
		{ "ae5b7951-95cd-43aa-9b36-65de906882e0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "293fdc86-84fc-4386-a4ea-e3e7377a7be7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ae5b7951-95cd-43aa-9b36-65de906882e0") },
		{ "93d7c9f5-c066-4e60-b633-5be0ef2807b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Equal), "94f3e71d-d5bc-4424-addf-9ff48a5358d7"},}, new Dictionary<Terminator, ReduceInformation>{ }, "93d7c9f5-c066-4e60-b633-5be0ef2807b8") },
		{ "912e4da1-e8fb-4a38-8030-e12208663cc8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "912e4da1-e8fb-4a38-8030-e12208663cc8") },
		{ "781c1c65-aace-4a9f-99a0-27db800d49de", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "be4a9c74-bc5a-4844-8801-ca1268a35e55"},}, new Dictionary<Terminator, ReduceInformation>{ }, "781c1c65-aace-4a9f-99a0-27db800d49de") },
		{ "b8fcf909-531f-4031-9b0d-6918b017877b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "e6327efe-cfff-4534-975c-d1b2e2b90b29"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b8fcf909-531f-4031-9b0d-6918b017877b") },
		{ "7cfe0e9a-5fa8-4b51-a756-42ba64deebce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ConstValue))}, }, "7cfe0e9a-5fa8-4b51-a756-42ba64deebce") },
		{ "614f21e7-00f7-4874-bbcd-27b78c54917a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ConstValue))}, }, "614f21e7-00f7-4874-bbcd-27b78c54917a") },
		{ "c8bd17aa-2a90-4757-ae25-ea4598ab61dd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "c8bd17aa-2a90-4757-ae25-ea4598ab61dd") },
		{ "690bea35-3943-4411-8844-cc7656fc6ba3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "4b0b5f00-9646-465a-ad7b-0fed89a0a8a8"}, { new Terminator(DelimiterType.Semicolon), "fad9faa7-530f-483a-8fae-ecc0e45f8c81"},}, new Dictionary<Terminator, ReduceInformation>{ }, "690bea35-3943-4411-8844-cc7656fc6ba3") },
		{ "fdd837f2-ea2b-4b7d-b508-9ae3784e8527", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.StatementList))}, }, "fdd837f2-ea2b-4b7d-b508-9ae3784e8527") },
		{ "cbf78e0e-30be-444a-a889-49dada542a18", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "ba509327-54ec-433c-9d58-c7300e8450d1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cbf78e0e-30be-444a-a889-49dada542a18") },
		{ "b9d781e7-855d-47cf-9956-a824e41500d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "04098fde-e02b-4cdc-81db-5fe8f1ac5832"}, { new NonTerminator(NonTerminatorType.IdVarPart), "7e9397e5-09be-4410-84fe-8173c20828d0"}, { new Terminator(DelimiterType.LeftSquareBracket), "fa4d97ff-0efb-48f4-9949-b02609473f51"}, { new Terminator(DelimiterType.LeftParenthesis), "ce8c3165-cca9-4d3e-8b64-692a148eaeeb"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "b9d781e7-855d-47cf-9956-a824e41500d0") },
		{ "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d") },
		{ "74b98ed9-2c2c-4413-9b2d-d0a74162f661", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "74b98ed9-2c2c-4413-9b2d-d0a74162f661") },
		{ "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f856e845-bb6f-4846-8da0-941e910787dc"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "ebfdbee0-c036-4f2b-b781-609955bc5ade"}, { new NonTerminator(NonTerminatorType.Term), "47f6dd1e-39c8-4093-887d-8a2bb3c13b00"}, { new NonTerminator(NonTerminatorType.Factor), "d6e81138-4a05-4c34-8bc6-778e7f368ff6"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17") },
		{ "1e574cb3-c9a8-48d8-b351-9172a92b168d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "3aa1c1a6-1113-4a3c-8908-bed4dbc33ae2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1e574cb3-c9a8-48d8-b351-9172a92b168d") },
		{ "23caac79-74dd-413b-a5f5-f37380c3e5f9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "84e58b03-2379-4f5b-97bf-54cc4454c0c7"}, { new NonTerminator(NonTerminatorType.Statement), "fdd837f2-ea2b-4b7d-b508-9ae3784e8527"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "23caac79-74dd-413b-a5f5-f37380c3e5f9") },
		{ "706956c0-39db-4fb3-a8e8-bd30d7971735", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Procedure), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, { new Terminator(KeywordType.Function), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramDeclarations))}, }, "706956c0-39db-4fb3-a8e8-bd30d7971735") },
		{ "b0d7660b-c146-4468-8e49-95f98e057cb3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SubprogramBody), "f6c6560a-7338-432e-96e5-93e5a5603604"}, { new NonTerminator(NonTerminatorType.ConstDeclarations), "174781aa-004a-40b8-82bd-b23a03f6923e"}, { new Terminator(KeywordType.Const), "7116fc9f-7dd5-4b9e-9995-0a3d24ed7b56"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, { new Terminator(KeywordType.Var), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ConstDeclarations))}, }, "b0d7660b-c146-4468-8e49-95f98e057cb3") },
		{ "72b7ac1c-9458-4b3b-9ef4-6c4e896b3b04", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "76522d7d-e22c-46b9-9293-19fa918e52e0"}, { new Terminator(DelimiterType.LeftParenthesis), "91317386-5371-473c-a6f1-d66e78af0cfa"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "72b7ac1c-9458-4b3b-9ef4-6c4e896b3b04") },
		{ "608a01ce-ac56-4141-89f7-d7177e0fd7d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.FormalParameter), "778b38e7-aec8-4c5b-823e-11b5ac8d875a"}, { new Terminator(DelimiterType.LeftParenthesis), "ed8b175d-0e9e-4993-8bdd-b5924239607b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "608a01ce-ac56-4141-89f7-d7177e0fd7d1") },
		{ "f85556a6-d6d4-4cfb-a5f2-5e1b809e273c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "708d80b6-a05c-4a37-9dab-4ecc0cbed61a"}, { new Terminator(DelimiterType.Comma), "ae5b7951-95cd-43aa-9b36-65de906882e0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f85556a6-d6d4-4cfb-a5f2-5e1b809e273c") },
		{ "9e325725-9124-465d-b265-b7e686bfefb8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "9e325725-9124-465d-b265-b7e686bfefb8") },
		{ "4813c436-65fe-414d-bf37-063661cce00d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Type))}, }, "4813c436-65fe-414d-bf37-063661cce00d") },
		{ "dc6b04bc-1024-4c2b-9e7e-cb431d368490", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftSquareBracket), "2ec6f9dc-4599-4cc3-968e-7f2c884f4710"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dc6b04bc-1024-4c2b-9e7e-cb431d368490") },
		{ "af867cb8-3fd0-40d2-93ed-821588536cd6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "af867cb8-3fd0-40d2-93ed-821588536cd6") },
		{ "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498") },
		{ "e7f508c2-f944-4a52-82c9-2c1da660b58e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "e7f508c2-f944-4a52-82c9-2c1da660b58e") },
		{ "50dac50a-0c16-462e-934c-bcce04c19b99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "50dac50a-0c16-462e-934c-bcce04c19b99") },
		{ "293fdc86-84fc-4386-a4ea-e3e7377a7be7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdentifierList))}, }, "293fdc86-84fc-4386-a4ea-e3e7377a7be7") },
		{ "94f3e71d-d5bc-4424-addf-9ff48a5358d7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ConstValue), "a7a26936-4976-4469-a09c-7b120dce53db"}, { new Terminator(OperatorType.Plus), "781c1c65-aace-4a9f-99a0-27db800d49de"}, { new Terminator(OperatorType.Minus), "b8fcf909-531f-4031-9b0d-6918b017877b"}, { Terminator.NumberTerminator, "7cfe0e9a-5fa8-4b51-a756-42ba64deebce"}, { Terminator.CharacterTerminator, "614f21e7-00f7-4874-bbcd-27b78c54917a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "94f3e71d-d5bc-4424-addf-9ff48a5358d7") },
		{ "be4a9c74-bc5a-4844-8801-ca1268a35e55", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "be4a9c74-bc5a-4844-8801-ca1268a35e55") },
		{ "e6327efe-cfff-4534-975c-d1b2e2b90b29", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ConstValue))}, }, "e6327efe-cfff-4534-975c-d1b2e2b90b29") },
		{ "4b0b5f00-9646-465a-ad7b-0fed89a0a8a8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Period), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "4b0b5f00-9646-465a-ad7b-0fed89a0a8a8") },
		{ "fad9faa7-530f-483a-8fae-ecc0e45f8c81", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "5228830a-a93c-4f70-8967-392c61fab131"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "fad9faa7-530f-483a-8fae-ecc0e45f8c81") },
		{ "ba509327-54ec-433c-9d58-c7300e8450d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "5ad8ae4f-fc29-403e-94ca-cd7626723e9f"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "420e5485-e02b-4c90-ad4e-9feeeba8fd99"}, { new NonTerminator(NonTerminatorType.Term), "460c20d2-8e14-425e-ae0b-2b5cf042cc06"}, { new NonTerminator(NonTerminatorType.Factor), "f518e484-1177-4635-87bd-feea4af66cc2"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ba509327-54ec-433c-9d58-c7300e8450d1") },
		{ "04098fde-e02b-4cdc-81db-5fe8f1ac5832", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "8272f2c1-371d-425a-b649-8fe4a09db0aa"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "420e5485-e02b-4c90-ad4e-9feeeba8fd99"}, { new NonTerminator(NonTerminatorType.Term), "460c20d2-8e14-425e-ae0b-2b5cf042cc06"}, { new NonTerminator(NonTerminatorType.Factor), "f518e484-1177-4635-87bd-feea4af66cc2"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "04098fde-e02b-4cdc-81db-5fe8f1ac5832") },
		{ "7e9397e5-09be-4410-84fe-8173c20828d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "7e9397e5-09be-4410-84fe-8173c20828d0") },
		{ "fa4d97ff-0efb-48f4-9949-b02609473f51", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8d930400-d6a9-4454-89a1-3aaf94df118f"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fa4d97ff-0efb-48f4-9949-b02609473f51") },
		{ "ce8c3165-cca9-4d3e-8b64-692a148eaeeb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "f4df3428-9972-407b-bd0b-974f01339c2d"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ce8c3165-cca9-4d3e-8b64-692a148eaeeb") },
		{ "f856e845-bb6f-4846-8da0-941e910787dc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "b37b6c22-4c5f-49fb-ab2f-58ddf8c3ac2b"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f856e845-bb6f-4846-8da0-941e910787dc") },
		{ "ebfdbee0-c036-4f2b-b781-609955bc5ade", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "f186d2a0-bc47-4435-ae8b-5d00b71dee25"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "4b89b161-7dd4-4236-a4fa-b692b9607162"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "ebfdbee0-c036-4f2b-b781-609955bc5ade") },
		{ "47f6dd1e-39c8-4093-887d-8a2bb3c13b00", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "2857e805-3473-4c3a-ba75-7377d03c4656"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "47f6dd1e-39c8-4093-887d-8a2bb3c13b00") },
		{ "d6e81138-4a05-4c34-8bc6-778e7f368ff6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "d6e81138-4a05-4c34-8bc6-778e7f368ff6") },
		{ "2924cf68-f54b-4d77-a0f9-ce3c92764bf5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5") },
		{ "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a") },
		{ "5fb0de2d-e007-4285-9c6c-5961c728646a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "fd97ed26-3665-4864-9142-4bff1cba29c2"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5fb0de2d-e007-4285-9c6c-5961c728646a") },
		{ "eb73ddc3-ff88-46fe-a454-562c1e51cba2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "b460f5e2-cee7-4c15-95a3-fabdb39b238c"}, { new NonTerminator(NonTerminatorType.IdVarPart), "c633fed5-adee-49c5-b377-ffdbfdb492af"}, { new Terminator(DelimiterType.LeftSquareBracket), "18e74c81-063a-4233-88fb-f40f506afdc6"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "eb73ddc3-ff88-46fe-a454-562c1e51cba2") },
		{ "d5a5fcc4-47b3-40ef-8d8e-45f675af525e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "fa435d3d-ed79-48c0-a5fe-dd53dc0ac147"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d5a5fcc4-47b3-40ef-8d8e-45f675af525e") },
		{ "6e543d95-4133-4cb8-9af1-6c45a4e68f97", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "8806cb73-2c0e-4153-99a1-d1deded7b4be"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6e543d95-4133-4cb8-9af1-6c45a4e68f97") },
		{ "3aa1c1a6-1113-4a3c-8908-bed4dbc33ae2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "59d2ce94-6765-40f2-be23-ba0203e50f27"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3aa1c1a6-1113-4a3c-8908-bed4dbc33ae2") },
		{ "84e58b03-2379-4f5b-97bf-54cc4454c0c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "21bf1c5d-01ae-44fd-b35c-d34267ce5808"}, { new Terminator(DelimiterType.Semicolon), "fad9faa7-530f-483a-8fae-ecc0e45f8c81"},}, new Dictionary<Terminator, ReduceInformation>{ }, "84e58b03-2379-4f5b-97bf-54cc4454c0c7") },
		{ "f6c6560a-7338-432e-96e5-93e5a5603604", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Subprogram))}, }, "f6c6560a-7338-432e-96e5-93e5a5603604") },
		{ "174781aa-004a-40b8-82bd-b23a03f6923e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.VarDeclarations), "da9087d2-9f5c-4040-b8c8-69693cc529fd"}, { new Terminator(KeywordType.Var), "926c4c53-ec6c-409f-96a7-29807e9b065a"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Begin), new ReduceInformation(0, new NonTerminator(NonTerminatorType.VarDeclarations))}, }, "174781aa-004a-40b8-82bd-b23a03f6923e") },
		{ "76522d7d-e22c-46b9-9293-19fa918e52e0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "76522d7d-e22c-46b9-9293-19fa918e52e0") },
		{ "91317386-5371-473c-a6f1-d66e78af0cfa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "d56e1087-2abe-479d-a783-e0dba160d752"}, { new NonTerminator(NonTerminatorType.Parameter), "968c819a-f6ef-444c-85cd-39e7994ef823"}, { new NonTerminator(NonTerminatorType.VarParameter), "15672cf4-8391-4737-97dc-2208966252c2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "725bf017-6220-438e-95cc-6443f64b4b87"}, { new Terminator(KeywordType.Var), "34a556b4-5749-4a87-b1e1-f205c60200f0"}, { new NonTerminator(NonTerminatorType.IdentifierList), "06ec5d96-5848-4294-8e2f-d5a7b2f605bc"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "91317386-5371-473c-a6f1-d66e78af0cfa") },
		{ "778b38e7-aec8-4c5b-823e-11b5ac8d875a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "faa1594f-4269-42de-b872-8cb07aeda99e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "778b38e7-aec8-4c5b-823e-11b5ac8d875a") },
		{ "ed8b175d-0e9e-4993-8bdd-b5924239607b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ParameterList), "ff5f5b8d-b108-4403-a904-8a15751dd792"}, { new NonTerminator(NonTerminatorType.Parameter), "968c819a-f6ef-444c-85cd-39e7994ef823"}, { new NonTerminator(NonTerminatorType.VarParameter), "15672cf4-8391-4737-97dc-2208966252c2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "725bf017-6220-438e-95cc-6443f64b4b87"}, { new Terminator(KeywordType.Var), "34a556b4-5749-4a87-b1e1-f205c60200f0"}, { new NonTerminator(NonTerminatorType.IdentifierList), "06ec5d96-5848-4294-8e2f-d5a7b2f605bc"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ed8b175d-0e9e-4993-8bdd-b5924239607b") },
		{ "708d80b6-a05c-4a37-9dab-4ecc0cbed61a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Type), "3ac5d87d-eba4-400a-af8e-809dc9b3c221"}, { new NonTerminator(NonTerminatorType.BasicType), "4813c436-65fe-414d-bf37-063661cce00d"}, { new Terminator(KeywordType.Array), "dc6b04bc-1024-4c2b-9e7e-cb431d368490"}, { new Terminator(KeywordType.Integer), "af867cb8-3fd0-40d2-93ed-821588536cd6"}, { new Terminator(KeywordType.Real), "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498"}, { new Terminator(KeywordType.Boolean), "e7f508c2-f944-4a52-82c9-2c1da660b58e"}, { new Terminator(KeywordType.Character), "50dac50a-0c16-462e-934c-bcce04c19b99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "708d80b6-a05c-4a37-9dab-4ecc0cbed61a") },
		{ "2ec6f9dc-4599-4cc3-968e-7f2c884f4710", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Period), "febab4a9-9511-48b9-ade6-c86f057f0934"}, { Terminator.NumberTerminator, "83113822-9be6-4e37-a474-66dcba22af7a"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2ec6f9dc-4599-4cc3-968e-7f2c884f4710") },
		{ "a7a26936-4976-4469-a09c-7b120dce53db", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.ConstDeclaration))}, }, "a7a26936-4976-4469-a09c-7b120dce53db") },
		{ "5228830a-a93c-4f70-8967-392c61fab131", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.StatementList))}, }, "5228830a-a93c-4f70-8967-392c61fab131") },
		{ "5ad8ae4f-fc29-403e-94ca-cd7626723e9f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "5ad8ae4f-fc29-403e-94ca-cd7626723e9f") },
		{ "420e5485-e02b-4c90-ad4e-9feeeba8fd99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "e5761f21-a033-4734-9f8f-5defcec96606"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "5ed63c52-0365-4aeb-ad95-1e7cadd23f87"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "420e5485-e02b-4c90-ad4e-9feeeba8fd99") },
		{ "460c20d2-8e14-425e-ae0b-2b5cf042cc06", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "95a45cb2-0595-4ebb-a74d-6b0640876e4c"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "460c20d2-8e14-425e-ae0b-2b5cf042cc06") },
		{ "f518e484-1177-4635-87bd-feea4af66cc2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "f518e484-1177-4635-87bd-feea4af66cc2") },
		{ "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4") },
		{ "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f") },
		{ "abd4a9b7-005f-47b2-9ff3-9065292782f7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f3648024-115f-407d-910e-5adfbe403652"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "abd4a9b7-005f-47b2-9ff3-9065292782f7") },
		{ "33117bf8-1be5-41d0-b93b-8ebf198d6c08", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "fe5f82d2-b25e-447b-9361-ba4bc789cef5"}, { new NonTerminator(NonTerminatorType.IdVarPart), "20823791-c15d-4f44-9288-cfd1cb8b4b78"}, { new Terminator(DelimiterType.LeftSquareBracket), "6af59aca-62d2-4168-8bd5-4dba79feb499"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "33117bf8-1be5-41d0-b93b-8ebf198d6c08") },
		{ "2348e8c3-ed00-40ce-9aa3-93e023534bcf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "67bd194f-b827-4be9-bd23-f5527afebf19"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2348e8c3-ed00-40ce-9aa3-93e023534bcf") },
		{ "1274f530-71c6-4cac-8d27-ba86fa480187", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "7a74d0c3-6a0a-40a1-9402-2a4ca09f77bf"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1274f530-71c6-4cac-8d27-ba86fa480187") },
		{ "8272f2c1-371d-425a-b649-8fe4a09db0aa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "8272f2c1-371d-425a-b649-8fe4a09db0aa") },
		{ "8d930400-d6a9-4454-89a1-3aaf94df118f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "6a8cfdb6-12c8-48ba-b3ab-ae32456164ce"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8d930400-d6a9-4454-89a1-3aaf94df118f") },
		{ "fed37968-d822-446a-ac23-a1c709636058", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "fed37968-d822-446a-ac23-a1c709636058") },
		{ "8674abec-86a6-45fb-bbf9-7212155c0a45", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "a2c516ed-bd4b-40df-949f-bd05f40cf8dc"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "d73de74c-c23e-4252-8b9c-bf6514cfb350"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "8674abec-86a6-45fb-bbf9-7212155c0a45") },
		{ "24beb9a9-8c5c-49a1-9dff-f50d06306e7e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "1395300a-3abf-4fb9-84e8-0caabe5e770e"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "24beb9a9-8c5c-49a1-9dff-f50d06306e7e") },
		{ "b7e313c6-3274-404b-b681-fea2f0476fe9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "b7e313c6-3274-404b-b681-fea2f0476fe9") },
		{ "a90cc1fe-fe7b-433d-8e5c-9e14989b1063", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063") },
		{ "b6f34cf6-843f-4381-9313-c048737ee827", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "b6f34cf6-843f-4381-9313-c048737ee827") },
		{ "b47fbc41-e16a-4357-bb83-24de77644b36", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "af41ac0e-76f5-4e37-8d17-931801b9d36f"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b47fbc41-e16a-4357-bb83-24de77644b36") },
		{ "1713c6c4-f2c4-4047-bfb9-9965cb913903", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "da2fcf5c-6628-4359-90d2-07b0d44cb8fb"}, { new NonTerminator(NonTerminatorType.IdVarPart), "8d65f0eb-a01e-498a-9d38-b86da6309d05"}, { new Terminator(DelimiterType.LeftSquareBracket), "571ce61f-e49c-4eea-a65e-6f666afc764c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "1713c6c4-f2c4-4047-bfb9-9965cb913903") },
		{ "f3b32425-ac50-4033-86e2-f3088f94ac5a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4ba86d63-1273-43e7-961d-93162babcde1"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f3b32425-ac50-4033-86e2-f3088f94ac5a") },
		{ "3a223695-8674-4413-b39f-d5c9812ff660", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "ac513162-fe19-44d0-9295-0ed8248bcee5"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3a223695-8674-4413-b39f-d5c9812ff660") },
		{ "f4df3428-9972-407b-bd0b-974f01339c2d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "befbb070-11d8-4a20-aeb1-5c4551a98d6d"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f4df3428-9972-407b-bd0b-974f01339c2d") },
		{ "42cec062-e3c3-4677-824f-cdf54a69a96d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "42cec062-e3c3-4677-824f-cdf54a69a96d") },
		{ "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "425bc9d7-5f55-4b0b-aba1-8f61a852a4e8"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "127c6b74-f4b3-447e-aa39-611f1e2da17c"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc") },
		{ "d45f1af1-d596-4ff3-ba54-bf0a96485caa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "8f9af640-1f9d-45fa-a72f-81aeb455202d"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "d45f1af1-d596-4ff3-ba54-bf0a96485caa") },
		{ "84b00276-3b69-49e5-8f8e-57d37861e592", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "84b00276-3b69-49e5-8f8e-57d37861e592") },
		{ "9b4dbc9e-3a03-4126-9252-97d5b0bd1486", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486") },
		{ "50bdb82b-22d8-40ab-90ed-a0cb47b37e31", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "50bdb82b-22d8-40ab-90ed-a0cb47b37e31") },
		{ "88c807ca-f1ff-40f4-9ca9-f58790021817", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "93f65023-864e-4e48-a28a-58b3268ed0f4"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "88c807ca-f1ff-40f4-9ca9-f58790021817") },
		{ "349b78b5-cf5e-45b6-82e3-c4de09db7f9c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "c4776dfa-bbdd-4241-949d-0c77e5f5cc4f"}, { new NonTerminator(NonTerminatorType.IdVarPart), "d0ad6128-b518-4f14-8103-c8be0e81ae1c"}, { new Terminator(DelimiterType.LeftSquareBracket), "c898ade9-114c-406c-9b68-7b58ee876a9f"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c") },
		{ "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "a3167e5e-5b71-4dad-bf2a-ca19e837c056"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99") },
		{ "20009023-7acd-4763-8234-1127840c6bb8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "31ba62f7-1378-4d1b-84d2-f1881bfd3073"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "20009023-7acd-4763-8234-1127840c6bb8") },
		{ "b37b6c22-4c5f-49fb-ab2f-58ddf8c3ac2b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "821760b0-5b60-479f-9058-f74add1d4b1b"}, { new NonTerminator(NonTerminatorType.Variable), "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1"}, { Terminator.IdentifierTerminator, "0375bfdc-70d2-4173-820c-c00295879eb4"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "1166a74d-cd84-447a-884e-6e994b426865"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "35103497-0e41-4976-8eaf-a6784e27cad6"}, { new Terminator(KeywordType.If), "158f9f5f-b96c-400b-aea4-d420cac1e1f5"}, { new Terminator(KeywordType.For), "e5eae017-43f9-43a5-8cc6-b467d75a7d5d"}, { new Terminator(KeywordType.Begin), "5342eece-10e0-4678-9b11-0dfece0a51b4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "b37b6c22-4c5f-49fb-ab2f-58ddf8c3ac2b") },
		{ "f186d2a0-bc47-4435-ae8b-5d00b71dee25", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "d2bd67e4-9c6d-4f3d-ae34-2afe8fbf9c24"}, { new NonTerminator(NonTerminatorType.Term), "0365c2e9-afda-402a-84be-4e10060fd38e"}, { new NonTerminator(NonTerminatorType.Factor), "83ffeb68-ea6d-4577-8175-80014c07c5ec"}, { Terminator.NumberTerminator, "9a5d3e85-90c6-487a-bf96-172efedb856a"}, { new NonTerminator(NonTerminatorType.Variable), "fc5d3570-ef84-49c0-8351-2db09f504e50"}, { new Terminator(DelimiterType.LeftParenthesis), "69ace23c-8c28-471e-91ac-21a82cffafa9"}, { Terminator.IdentifierTerminator, "3292a333-3a9a-4a7f-913d-66352cd05e41"}, { new Terminator(KeywordType.Not), "519bf42f-444f-42bf-a6d1-5e8fdbbba37c"}, { new Terminator(OperatorType.Minus), "41e1690e-37ab-43a5-9a15-c546e9726ebd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f186d2a0-bc47-4435-ae8b-5d00b71dee25") },
		{ "687ec427-3947-4e5c-8d56-37456f7c831b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "687ec427-3947-4e5c-8d56-37456f7c831b") },
		{ "ae2cc3fd-452f-4a67-bc6e-42bc038aae93", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "ae2cc3fd-452f-4a67-bc6e-42bc038aae93") },
		{ "491dd600-6fe1-4b4e-944c-44b15d27cddb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "491dd600-6fe1-4b4e-944c-44b15d27cddb") },
		{ "ea5f6ee8-d519-4361-8fcf-0543369675c7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "ea5f6ee8-d519-4361-8fcf-0543369675c7") },
		{ "99f43ff3-6ead-488e-91b6-ec4d6d34447d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "99f43ff3-6ead-488e-91b6-ec4d6d34447d") },
		{ "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.RelationOperator))}, }, "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1") },
		{ "4b89b161-7dd4-4236-a4fa-b692b9607162", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "25e25c1f-7509-4c9e-b8b6-57a58afb54c5"}, { new NonTerminator(NonTerminatorType.Factor), "d6e81138-4a05-4c34-8bc6-778e7f368ff6"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4b89b161-7dd4-4236-a4fa-b692b9607162") },
		{ "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd") },
		{ "ded9c168-151c-4d84-9ea8-b1b9c89f4b42", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "ded9c168-151c-4d84-9ea8-b1b9c89f4b42") },
		{ "74a6434c-3d29-45af-9711-0e57dd9a2b7c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.AddOperator))}, }, "74a6434c-3d29-45af-9711-0e57dd9a2b7c") },
		{ "2857e805-3473-4c3a-ba75-7377d03c4656", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "4e9dd872-0ac9-4b3b-b6d5-0c99170afceb"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2857e805-3473-4c3a-ba75-7377d03c4656") },
		{ "0eca1a66-008d-4c96-b177-2bfbaee76e2c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "0eca1a66-008d-4c96-b177-2bfbaee76e2c") },
		{ "ad4dc115-e8ac-460d-a3f3-3f99aeb88803", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "ad4dc115-e8ac-460d-a3f3-3f99aeb88803") },
		{ "820ae9cc-7b03-4a73-a7db-487c6452a91e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "820ae9cc-7b03-4a73-a7db-487c6452a91e") },
		{ "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6") },
		{ "6551cb6c-d1cb-41e4-9850-08ac8a227d44", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { Terminator.NumberTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { Terminator.IdentifierTerminator, new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(DelimiterType.LeftParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(KeywordType.Not), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.MultiplyOperator))}, }, "6551cb6c-d1cb-41e4-9850-08ac8a227d44") },
		{ "fd97ed26-3665-4864-9142-4bff1cba29c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "3492d5ed-4bcf-45b0-983d-3f40d1f139ac"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fd97ed26-3665-4864-9142-4bff1cba29c2") },
		{ "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "d9de7133-ef44-45bb-868c-7964f104ae7b"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "eb70d202-ad23-4d6f-a350-eb07b21e0970"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc") },
		{ "061d0a90-dc23-4393-b750-6c90f01d0fa1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "60e3a830-2cc0-4e3e-a30c-38d6a442c522"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "061d0a90-dc23-4393-b750-6c90f01d0fa1") },
		{ "a18f53ac-d7c5-49c4-bdd5-8483389d4c25", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "a18f53ac-d7c5-49c4-bdd5-8483389d4c25") },
		{ "94deaa4e-cb74-418b-b853-495567a0a29d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "94deaa4e-cb74-418b-b853-495567a0a29d") },
		{ "c0a01468-a7ac-497b-bd1c-441c1a1f1e17", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "c0a01468-a7ac-497b-bd1c-441c1a1f1e17") },
		{ "ddfc779c-0286-4ef9-af0b-17e404947c61", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "d9f8f956-94dd-4b63-923d-eed6077368da"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ddfc779c-0286-4ef9-af0b-17e404947c61") },
		{ "838078c9-e208-461b-a70f-bef9dda8b800", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "9299bfca-2f8e-4f10-b12d-9e3c193c0130"}, { new NonTerminator(NonTerminatorType.IdVarPart), "02a298e0-9e2f-45a8-a6b5-05ab7a5816ee"}, { new Terminator(DelimiterType.LeftSquareBracket), "0445585c-0d47-4e01-b4d0-3c64512650e4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "838078c9-e208-461b-a70f-bef9dda8b800") },
		{ "d850eaa2-f595-459f-8c6a-0009fb6fe711", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "5ff1e825-4465-434a-8f28-279fd085a36b"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d850eaa2-f595-459f-8c6a-0009fb6fe711") },
		{ "0e05980a-6d1c-4861-bf49-081c9a58f840", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "2574ecb8-19c2-4516-98b7-8854a35c680d"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0e05980a-6d1c-4861-bf49-081c9a58f840") },
		{ "b460f5e2-cee7-4c15-95a3-fabdb39b238c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "9c0c4b1f-8d76-4e97-9e3c-1e5f1998f5a9"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b460f5e2-cee7-4c15-95a3-fabdb39b238c") },
		{ "c633fed5-adee-49c5-b377-ffdbfdb492af", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "c633fed5-adee-49c5-b377-ffdbfdb492af") },
		{ "18e74c81-063a-4233-88fb-f40f506afdc6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "913774f1-6a72-42a4-8508-90f6539e2a47"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "18e74c81-063a-4233-88fb-f40f506afdc6") },
		{ "fa435d3d-ed79-48c0-a5fe-dd53dc0ac147", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "fa435d3d-ed79-48c0-a5fe-dd53dc0ac147") },
		{ "8806cb73-2c0e-4153-99a1-d1deded7b4be", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "8806cb73-2c0e-4153-99a1-d1deded7b4be") },
		{ "59d2ce94-6765-40f2-be23-ba0203e50f27", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "6148effd-d000-42a6-8eff-d334a6eab4d1"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "c627f7e8-db78-474b-ae8a-676215a5cd02"}, { new NonTerminator(NonTerminatorType.Term), "3410b4c1-8faf-45a4-b48d-636916e1a449"}, { new NonTerminator(NonTerminatorType.Factor), "a1220313-359c-4239-94ef-09d472d79efc"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "59d2ce94-6765-40f2-be23-ba0203e50f27") },
		{ "21bf1c5d-01ae-44fd-b35c-d34267ce5808", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "21bf1c5d-01ae-44fd-b35c-d34267ce5808") },
		{ "da9087d2-9f5c-4040-b8c8-69693cc529fd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.CompoundStatement), "13cdc331-b3fc-461f-88ac-38f5a7c42646"}, { new Terminator(KeywordType.Begin), "b8cb4275-f568-4aab-865f-16c2c2736bd9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "da9087d2-9f5c-4040-b8c8-69693cc529fd") },
		{ "d56e1087-2abe-479d-a783-e0dba160d752", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8d05af01-92e9-4b29-bcfe-a8ef805512e8"}, { new Terminator(DelimiterType.Semicolon), "856726d4-f9a1-4f6d-9123-fd9705bfafbd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d56e1087-2abe-479d-a783-e0dba160d752") },
		{ "968c819a-f6ef-444c-85cd-39e7994ef823", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ParameterList))}, }, "968c819a-f6ef-444c-85cd-39e7994ef823") },
		{ "15672cf4-8391-4737-97dc-2208966252c2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "15672cf4-8391-4737-97dc-2208966252c2") },
		{ "725bf017-6220-438e-95cc-6443f64b4b87", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Parameter))}, }, "725bf017-6220-438e-95cc-6443f64b4b87") },
		{ "34a556b4-5749-4a87-b1e1-f205c60200f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ValueParameter), "f1143c4d-33c0-499e-ac5f-b7023f960c77"}, { new NonTerminator(NonTerminatorType.IdentifierList), "06ec5d96-5848-4294-8e2f-d5a7b2f605bc"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34a556b4-5749-4a87-b1e1-f205c60200f0") },
		{ "06ec5d96-5848-4294-8e2f-d5a7b2f605bc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.Colon), "945cc5d1-3dfd-4340-93d5-05be48c6e236"}, { new Terminator(DelimiterType.Comma), "ae5b7951-95cd-43aa-9b36-65de906882e0"},}, new Dictionary<Terminator, ReduceInformation>{ }, "06ec5d96-5848-4294-8e2f-d5a7b2f605bc") },
		{ "faa1594f-4269-42de-b872-8cb07aeda99e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "02c8ecbb-3ebd-4823-bd4b-a9ea517715e0"}, { new Terminator(KeywordType.Integer), "af867cb8-3fd0-40d2-93ed-821588536cd6"}, { new Terminator(KeywordType.Real), "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498"}, { new Terminator(KeywordType.Boolean), "e7f508c2-f944-4a52-82c9-2c1da660b58e"}, { new Terminator(KeywordType.Character), "50dac50a-0c16-462e-934c-bcce04c19b99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "faa1594f-4269-42de-b872-8cb07aeda99e") },
		{ "ff5f5b8d-b108-4403-a904-8a15751dd792", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "42d947ee-3a1a-4051-a8a2-9107628ba061"}, { new Terminator(DelimiterType.Semicolon), "856726d4-f9a1-4f6d-9123-fd9705bfafbd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ff5f5b8d-b108-4403-a904-8a15751dd792") },
		{ "3ac5d87d-eba4-400a-af8e-809dc9b3c221", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.VarDeclaration))}, }, "3ac5d87d-eba4-400a-af8e-809dc9b3c221") },
		{ "febab4a9-9511-48b9-ade6-c86f057f0934", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "34dc47bb-22ab-45f2-b96a-c46f3b7bb32b"}, { new Terminator(DelimiterType.Comma), "8c28c608-6ef0-4069-8e05-6a2f0a97ddb3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "febab4a9-9511-48b9-ade6-c86f057f0934") },
		{ "83113822-9be6-4e37-a474-66dcba22af7a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "fa3979f3-9012-408a-993e-b5f4d2a6c576"},}, new Dictionary<Terminator, ReduceInformation>{ }, "83113822-9be6-4e37-a474-66dcba22af7a") },
		{ "e5761f21-a033-4734-9f8f-5defcec96606", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "f2c41046-68b5-4f2f-b52d-fad57c7da07e"}, { new NonTerminator(NonTerminatorType.Term), "9efe492a-8b5d-4177-998c-19f101f6a3fa"}, { new NonTerminator(NonTerminatorType.Factor), "46ca7707-dc50-4ff1-9259-7bd864d9666e"}, { Terminator.NumberTerminator, "ed4ac725-60b5-49fe-b9f3-955cba35f640"}, { new NonTerminator(NonTerminatorType.Variable), "e1122f6f-dbba-4384-90a3-fe7ae63302bd"}, { new Terminator(DelimiterType.LeftParenthesis), "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11"}, { Terminator.IdentifierTerminator, "58d80663-e860-413b-8d28-0833007d4cf0"}, { new Terminator(KeywordType.Not), "8a5ba85a-39c9-4a84-9919-6cf571eae251"}, { new Terminator(OperatorType.Minus), "690c573f-5844-4d53-b011-a586179298d3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e5761f21-a033-4734-9f8f-5defcec96606") },
		{ "5ed63c52-0365-4aeb-ad95-1e7cadd23f87", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "6bd25941-410d-48ba-992d-3b4b3fa55244"}, { new NonTerminator(NonTerminatorType.Factor), "f518e484-1177-4635-87bd-feea4af66cc2"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5ed63c52-0365-4aeb-ad95-1e7cadd23f87") },
		{ "95a45cb2-0595-4ebb-a74d-6b0640876e4c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "025e3778-0c18-494c-b336-51d7ce62e08c"}, { Terminator.NumberTerminator, "6733ab88-6f1e-47b6-a0eb-7f1be4e4e9d4"}, { new NonTerminator(NonTerminatorType.Variable), "bd57c4ad-5509-4cbe-ba95-4e5a9b548b4f"}, { new Terminator(DelimiterType.LeftParenthesis), "abd4a9b7-005f-47b2-9ff3-9065292782f7"}, { Terminator.IdentifierTerminator, "33117bf8-1be5-41d0-b93b-8ebf198d6c08"}, { new Terminator(KeywordType.Not), "2348e8c3-ed00-40ce-9aa3-93e023534bcf"}, { new Terminator(OperatorType.Minus), "1274f530-71c6-4cac-8d27-ba86fa480187"},}, new Dictionary<Terminator, ReduceInformation>{ }, "95a45cb2-0595-4ebb-a74d-6b0640876e4c") },
		{ "f3648024-115f-407d-910e-5adfbe403652", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "9074a52b-01fb-48d6-bf47-f0307ddf8e3d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f3648024-115f-407d-910e-5adfbe403652") },
		{ "fe5f82d2-b25e-447b-9361-ba4bc789cef5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "42021cfa-b6cd-433e-99d6-2aa70c56d238"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fe5f82d2-b25e-447b-9361-ba4bc789cef5") },
		{ "20823791-c15d-4f44-9288-cfd1cb8b4b78", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "20823791-c15d-4f44-9288-cfd1cb8b4b78") },
		{ "6af59aca-62d2-4168-8bd5-4dba79feb499", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "803b51f4-e67d-4390-ae4e-1ba3f983cf01"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6af59aca-62d2-4168-8bd5-4dba79feb499") },
		{ "67bd194f-b827-4be9-bd23-f5527afebf19", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "67bd194f-b827-4be9-bd23-f5527afebf19") },
		{ "7a74d0c3-6a0a-40a1-9402-2a4ca09f77bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "7a74d0c3-6a0a-40a1-9402-2a4ca09f77bf") },
		{ "6a8cfdb6-12c8-48ba-b3ab-ae32456164ce", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "6a8cfdb6-12c8-48ba-b3ab-ae32456164ce") },
		{ "22b74200-b351-4d56-b227-baa12d161065", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "62d9e3d5-410f-4c77-a45c-cb7cea90473d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "22b74200-b351-4d56-b227-baa12d161065") },
		{ "a2c516ed-bd4b-40df-949f-bd05f40cf8dc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "03834caa-9dde-478e-8731-3e47b577ec37"}, { new NonTerminator(NonTerminatorType.Term), "ea6a8f39-394b-4186-962e-f355b741b702"}, { new NonTerminator(NonTerminatorType.Factor), "cec14544-b322-4990-aab8-d76f4cca6c2b"}, { Terminator.NumberTerminator, "dcde47e7-5026-4dde-8dcc-770aec831f2b"}, { new NonTerminator(NonTerminatorType.Variable), "b08c7e84-53a1-4b33-afe8-d6f8fd859cea"}, { new Terminator(DelimiterType.LeftParenthesis), "1522aa0c-6cd9-4af1-90f2-a55063c69a31"}, { Terminator.IdentifierTerminator, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f"}, { new Terminator(KeywordType.Not), "e635cd65-0abb-40cf-808b-469b663ab818"}, { new Terminator(OperatorType.Minus), "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a2c516ed-bd4b-40df-949f-bd05f40cf8dc") },
		{ "d73de74c-c23e-4252-8b9c-bf6514cfb350", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "edc2921d-abf6-4571-aec0-01079ab34025"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d73de74c-c23e-4252-8b9c-bf6514cfb350") },
		{ "1395300a-3abf-4fb9-84e8-0caabe5e770e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "e66d9dfa-089d-4e43-a99e-90437e2ffbc5"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1395300a-3abf-4fb9-84e8-0caabe5e770e") },
		{ "af41ac0e-76f5-4e37-8d17-931801b9d36f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "444f758d-223e-4aa7-8998-ffd99c4c82f6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "af41ac0e-76f5-4e37-8d17-931801b9d36f") },
		{ "da2fcf5c-6628-4359-90d2-07b0d44cb8fb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "d81c17f7-e6b8-4a13-a6e1-6811d4714db8"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "da2fcf5c-6628-4359-90d2-07b0d44cb8fb") },
		{ "8d65f0eb-a01e-498a-9d38-b86da6309d05", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "8d65f0eb-a01e-498a-9d38-b86da6309d05") },
		{ "571ce61f-e49c-4eea-a65e-6f666afc764c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "baa9f2b5-6f3e-47f1-810c-51abd07c0a6d"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "571ce61f-e49c-4eea-a65e-6f666afc764c") },
		{ "4ba86d63-1273-43e7-961d-93162babcde1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "4ba86d63-1273-43e7-961d-93162babcde1") },
		{ "ac513162-fe19-44d0-9295-0ed8248bcee5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "ac513162-fe19-44d0-9295-0ed8248bcee5") },
		{ "befbb070-11d8-4a20-aeb1-5c4551a98d6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "befbb070-11d8-4a20-aeb1-5c4551a98d6d") },
		{ "f9bc7017-c0f6-491e-9363-4a7bd45a0383", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "9f0f945f-012e-4508-943f-92f1ea0df9b8"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f9bc7017-c0f6-491e-9363-4a7bd45a0383") },
		{ "425bc9d7-5f55-4b0b-aba1-8f61a852a4e8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "fce83d48-f0d2-447d-b4c3-92d15ccb52f7"}, { new NonTerminator(NonTerminatorType.Term), "e3af1577-3d2d-42fa-bbb3-a6fb17f72f55"}, { new NonTerminator(NonTerminatorType.Factor), "9e547003-1a39-4700-b2f6-53bb37c9856b"}, { Terminator.NumberTerminator, "54f6d5f8-1848-426c-a42e-4590d41f479a"}, { new NonTerminator(NonTerminatorType.Variable), "6a2b5f1f-8656-4115-9912-599704decbdd"}, { new Terminator(DelimiterType.LeftParenthesis), "0971f571-b443-455b-b18b-dea3b710286e"}, { Terminator.IdentifierTerminator, "12530f8f-519d-475a-84a1-39ce3d90d01c"}, { new Terminator(KeywordType.Not), "ebdd204c-a99b-4345-953b-d1d98f0c8f92"}, { new Terminator(OperatorType.Minus), "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "425bc9d7-5f55-4b0b-aba1-8f61a852a4e8") },
		{ "127c6b74-f4b3-447e-aa39-611f1e2da17c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "ea42ea44-f610-4828-bfd6-000d11a1bf30"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "127c6b74-f4b3-447e-aa39-611f1e2da17c") },
		{ "8f9af640-1f9d-45fa-a72f-81aeb455202d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "1a16deba-c813-4ed4-818f-b9433f4b1919"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8f9af640-1f9d-45fa-a72f-81aeb455202d") },
		{ "93f65023-864e-4e48-a28a-58b3268ed0f4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "7a7cf14b-9abf-4f6a-839e-7e77491e4186"},}, new Dictionary<Terminator, ReduceInformation>{ }, "93f65023-864e-4e48-a28a-58b3268ed0f4") },
		{ "c4776dfa-bbdd-4241-949d-0c77e5f5cc4f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "f6834c8a-02b1-4ca4-ba9a-43a75cf9f946"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c4776dfa-bbdd-4241-949d-0c77e5f5cc4f") },
		{ "d0ad6128-b518-4f14-8103-c8be0e81ae1c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "d0ad6128-b518-4f14-8103-c8be0e81ae1c") },
		{ "c898ade9-114c-406c-9b68-7b58ee876a9f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "0960586b-bf2a-46d3-8d31-3d8f167c4f09"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c898ade9-114c-406c-9b68-7b58ee876a9f") },
		{ "a3167e5e-5b71-4dad-bf2a-ca19e837c056", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "a3167e5e-5b71-4dad-bf2a-ca19e837c056") },
		{ "31ba62f7-1378-4d1b-84d2-f1881bfd3073", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "31ba62f7-1378-4d1b-84d2-f1881bfd3073") },
		{ "821760b0-5b60-479f-9058-f74add1d4b1b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "52c6efd4-5584-4857-8971-f4118744fad4"}, { new Terminator(KeywordType.Else), "93cd56b4-f8f5-460b-890f-c9502f3e008b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "821760b0-5b60-479f-9058-f74add1d4b1b") },
		{ "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "43ed09a8-4d0e-4002-b556-a3631bb81a70"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1") },
		{ "0375bfdc-70d2-4173-820c-c00295879eb4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "af941e16-1c67-40cc-a850-2601bb91e263"}, { new NonTerminator(NonTerminatorType.IdVarPart), "7e9397e5-09be-4410-84fe-8173c20828d0"}, { new Terminator(DelimiterType.LeftSquareBracket), "fa4d97ff-0efb-48f4-9949-b02609473f51"}, { new Terminator(DelimiterType.LeftParenthesis), "a940fded-52ac-4e52-ab7f-f017a3423e33"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(OperatorType.Assign), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "0375bfdc-70d2-4173-820c-c00295879eb4") },
		{ "1166a74d-cd84-447a-884e-6e994b426865", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "1166a74d-cd84-447a-884e-6e994b426865") },
		{ "35103497-0e41-4976-8eaf-a6784e27cad6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Statement))}, }, "35103497-0e41-4976-8eaf-a6784e27cad6") },
		{ "158f9f5f-b96c-400b-aea4-d420cac1e1f5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "9a14aa6b-8e41-4d84-9f03-e4d7bee4336a"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "ebfdbee0-c036-4f2b-b781-609955bc5ade"}, { new NonTerminator(NonTerminatorType.Term), "47f6dd1e-39c8-4093-887d-8a2bb3c13b00"}, { new NonTerminator(NonTerminatorType.Factor), "d6e81138-4a05-4c34-8bc6-778e7f368ff6"}, { Terminator.NumberTerminator, "2924cf68-f54b-4d77-a0f9-ce3c92764bf5"}, { new NonTerminator(NonTerminatorType.Variable), "95769c1a-42ff-4fed-8e53-e0ce3cdbc34a"}, { new Terminator(DelimiterType.LeftParenthesis), "5fb0de2d-e007-4285-9c6c-5961c728646a"}, { Terminator.IdentifierTerminator, "eb73ddc3-ff88-46fe-a454-562c1e51cba2"}, { new Terminator(KeywordType.Not), "d5a5fcc4-47b3-40ef-8d8e-45f675af525e"}, { new Terminator(OperatorType.Minus), "6e543d95-4133-4cb8-9af1-6c45a4e68f97"},}, new Dictionary<Terminator, ReduceInformation>{ }, "158f9f5f-b96c-400b-aea4-d420cac1e1f5") },
		{ "e5eae017-43f9-43a5-8cc6-b467d75a7d5d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.IdentifierTerminator, "3634204b-806f-4052-a632-0d6ec9c36159"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e5eae017-43f9-43a5-8cc6-b467d75a7d5d") },
		{ "5342eece-10e0-4678-9b11-0dfece0a51b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "c780ec8e-bd81-474f-879a-d9549651cf13"}, { new NonTerminator(NonTerminatorType.Statement), "fdd837f2-ea2b-4b7d-b508-9ae3784e8527"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "5342eece-10e0-4678-9b11-0dfece0a51b4") },
		{ "d2bd67e4-9c6d-4f3d-ae34-2afe8fbf9c24", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "12e2617c-b7c2-4daf-a413-343130aa70fc"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "d2bd67e4-9c6d-4f3d-ae34-2afe8fbf9c24") },
		{ "0365c2e9-afda-402a-84be-4e10060fd38e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "e946d7cc-37cd-4257-ac3e-d4370582363c"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "0365c2e9-afda-402a-84be-4e10060fd38e") },
		{ "83ffeb68-ea6d-4577-8175-80014c07c5ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "83ffeb68-ea6d-4577-8175-80014c07c5ec") },
		{ "9a5d3e85-90c6-487a-bf96-172efedb856a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "9a5d3e85-90c6-487a-bf96-172efedb856a") },
		{ "fc5d3570-ef84-49c0-8351-2db09f504e50", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "fc5d3570-ef84-49c0-8351-2db09f504e50") },
		{ "69ace23c-8c28-471e-91ac-21a82cffafa9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "e3c8ec34-e9b4-416b-a18b-cda2a1152579"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "69ace23c-8c28-471e-91ac-21a82cffafa9") },
		{ "3292a333-3a9a-4a7f-913d-66352cd05e41", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "e3d09693-d886-41b9-8522-f17e7c3e734b"}, { new NonTerminator(NonTerminatorType.IdVarPart), "b1be5327-1efb-46b9-8fd7-a2bcac46fc19"}, { new Terminator(DelimiterType.LeftSquareBracket), "508985e2-1249-47a8-8a9a-3eeea359c0bf"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "3292a333-3a9a-4a7f-913d-66352cd05e41") },
		{ "519bf42f-444f-42bf-a6d1-5e8fdbbba37c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "6cac59ea-14f3-42e6-9e14-d18399ff8a79"}, { Terminator.NumberTerminator, "9a5d3e85-90c6-487a-bf96-172efedb856a"}, { new NonTerminator(NonTerminatorType.Variable), "fc5d3570-ef84-49c0-8351-2db09f504e50"}, { new Terminator(DelimiterType.LeftParenthesis), "69ace23c-8c28-471e-91ac-21a82cffafa9"}, { Terminator.IdentifierTerminator, "3292a333-3a9a-4a7f-913d-66352cd05e41"}, { new Terminator(KeywordType.Not), "519bf42f-444f-42bf-a6d1-5e8fdbbba37c"}, { new Terminator(OperatorType.Minus), "41e1690e-37ab-43a5-9a15-c546e9726ebd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "519bf42f-444f-42bf-a6d1-5e8fdbbba37c") },
		{ "41e1690e-37ab-43a5-9a15-c546e9726ebd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "449d55ac-3419-4930-b49a-a203f0aca2fe"}, { Terminator.NumberTerminator, "9a5d3e85-90c6-487a-bf96-172efedb856a"}, { new NonTerminator(NonTerminatorType.Variable), "fc5d3570-ef84-49c0-8351-2db09f504e50"}, { new Terminator(DelimiterType.LeftParenthesis), "69ace23c-8c28-471e-91ac-21a82cffafa9"}, { Terminator.IdentifierTerminator, "3292a333-3a9a-4a7f-913d-66352cd05e41"}, { new Terminator(KeywordType.Not), "519bf42f-444f-42bf-a6d1-5e8fdbbba37c"}, { new Terminator(OperatorType.Minus), "41e1690e-37ab-43a5-9a15-c546e9726ebd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "41e1690e-37ab-43a5-9a15-c546e9726ebd") },
		{ "25e25c1f-7509-4c9e-b8b6-57a58afb54c5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "2857e805-3473-4c3a-ba75-7377d03c4656"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "25e25c1f-7509-4c9e-b8b6-57a58afb54c5") },
		{ "4e9dd872-0ac9-4b3b-b6d5-0c99170afceb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "4e9dd872-0ac9-4b3b-b6d5-0c99170afceb") },
		{ "3492d5ed-4bcf-45b0-983d-3f40d1f139ac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "3492d5ed-4bcf-45b0-983d-3f40d1f139ac") },
		{ "d9de7133-ef44-45bb-868c-7964f104ae7b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "e4a94a94-9eab-423d-a565-bf04c6f376ff"}, { new NonTerminator(NonTerminatorType.Term), "6c614134-d955-4933-98d0-97cc4495f5ff"}, { new NonTerminator(NonTerminatorType.Factor), "646cc8a8-35dd-4ff8-a73e-85e67e40d7c4"}, { Terminator.NumberTerminator, "1c6b5b11-61f1-4492-8643-31a607b93b10"}, { new NonTerminator(NonTerminatorType.Variable), "1d17afa8-ed2c-4699-80ff-93e750e13e01"}, { new Terminator(DelimiterType.LeftParenthesis), "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3"}, { Terminator.IdentifierTerminator, "57310d2d-d905-455e-b7a4-2885e02e8a69"}, { new Terminator(KeywordType.Not), "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79"}, { new Terminator(OperatorType.Minus), "60a6366e-a4e6-4156-8dd7-c075e1384341"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d9de7133-ef44-45bb-868c-7964f104ae7b") },
		{ "eb70d202-ad23-4d6f-a350-eb07b21e0970", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "238e0ad3-d0af-4875-b450-91429f43152b"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eb70d202-ad23-4d6f-a350-eb07b21e0970") },
		{ "60e3a830-2cc0-4e3e-a30c-38d6a442c522", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3528c660-9c13-431d-bc41-ca80a4996990"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "60e3a830-2cc0-4e3e-a30c-38d6a442c522") },
		{ "d9f8f956-94dd-4b63-923d-eed6077368da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "7de92191-392b-48e8-aede-91997c3c3be2"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d9f8f956-94dd-4b63-923d-eed6077368da") },
		{ "9299bfca-2f8e-4f10-b12d-9e3c193c0130", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "fc32330f-a598-4838-b072-0b7486ae7a31"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9299bfca-2f8e-4f10-b12d-9e3c193c0130") },
		{ "02a298e0-9e2f-45a8-a6b5-05ab7a5816ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "02a298e0-9e2f-45a8-a6b5-05ab7a5816ee") },
		{ "0445585c-0d47-4e01-b4d0-3c64512650e4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "cb154a33-ed16-4fbd-82f4-c20a8c1719a3"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0445585c-0d47-4e01-b4d0-3c64512650e4") },
		{ "5ff1e825-4465-434a-8f28-279fd085a36b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "5ff1e825-4465-434a-8f28-279fd085a36b") },
		{ "2574ecb8-19c2-4516-98b7-8854a35c680d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "2574ecb8-19c2-4516-98b7-8854a35c680d") },
		{ "9c0c4b1f-8d76-4e97-9e3c-1e5f1998f5a9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a5fd6c1f-67b2-4d6d-951a-7c9edd4f720d"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9c0c4b1f-8d76-4e97-9e3c-1e5f1998f5a9") },
		{ "913774f1-6a72-42a4-8508-90f6539e2a47", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "2cf5715d-fac8-4eb2-be9c-5a4a4e6948ec"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "913774f1-6a72-42a4-8508-90f6539e2a47") },
		{ "6148effd-d000-42a6-8eff-d334a6eab4d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "644edcd6-0236-4a6b-a3cb-767f02323eb9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "6148effd-d000-42a6-8eff-d334a6eab4d1") },
		{ "c627f7e8-db78-474b-ae8a-676215a5cd02", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "a60c8f40-677e-412d-aeac-a071dd69570a"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "16d42ef1-b371-4fbc-b1bb-f15cfad159b5"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "c627f7e8-db78-474b-ae8a-676215a5cd02") },
		{ "3410b4c1-8faf-45a4-b48d-636916e1a449", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "88f40435-da28-4970-a1a5-87cd18d4b8c0"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "3410b4c1-8faf-45a4-b48d-636916e1a449") },
		{ "a1220313-359c-4239-94ef-09d472d79efc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "a1220313-359c-4239-94ef-09d472d79efc") },
		{ "c41f9918-370e-4391-bdb2-9ef02b7ee506", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "c41f9918-370e-4391-bdb2-9ef02b7ee506") },
		{ "a3380aa2-039f-4429-87f5-d1a103a15949", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "a3380aa2-039f-4429-87f5-d1a103a15949") },
		{ "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "69334b04-7159-4ad1-a966-80f80cb69461"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b") },
		{ "4ea9d59e-2f9a-4470-9f73-ec86a1242e06", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "1ede02b4-3fcf-4f76-9950-94ad8a0467b7"}, { new NonTerminator(NonTerminatorType.IdVarPart), "bcc1a319-703d-4eab-ac8a-8326de81a307"}, { new Terminator(DelimiterType.LeftSquareBracket), "33879ee8-9a89-405e-959c-ca66d26266e1"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06") },
		{ "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "db82a94f-eac4-4b64-a618-ae251c9f80e9"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf") },
		{ "8991e6dd-a23f-4139-970e-febccdbb3396", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "c5dbc2ef-4d81-45c7-92b8-9044ed6bc177"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8991e6dd-a23f-4139-970e-febccdbb3396") },
		{ "13cdc331-b3fc-461f-88ac-38f5a7c42646", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SubprogramBody))}, }, "13cdc331-b3fc-461f-88ac-38f5a7c42646") },
		{ "b8cb4275-f568-4aab-865f-16c2c2736bd9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.StatementList), "daf43aea-5fa8-4ace-96de-f620c2749bd4"}, { new NonTerminator(NonTerminatorType.Statement), "fdd837f2-ea2b-4b7d-b508-9ae3784e8527"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "b8cb4275-f568-4aab-865f-16c2c2736bd9") },
		{ "8d05af01-92e9-4b29-bcfe-a8ef805512e8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "8d05af01-92e9-4b29-bcfe-a8ef805512e8") },
		{ "856726d4-f9a1-4f6d-9123-fd9705bfafbd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Parameter), "6d68dd4b-5efb-4b7d-a4c6-2beab31e0d82"}, { new NonTerminator(NonTerminatorType.VarParameter), "15672cf4-8391-4737-97dc-2208966252c2"}, { new NonTerminator(NonTerminatorType.ValueParameter), "725bf017-6220-438e-95cc-6443f64b4b87"}, { new Terminator(KeywordType.Var), "34a556b4-5749-4a87-b1e1-f205c60200f0"}, { new NonTerminator(NonTerminatorType.IdentifierList), "06ec5d96-5848-4294-8e2f-d5a7b2f605bc"}, { Terminator.IdentifierTerminator, "69243085-a468-4c2a-8573-e0df8d82054f"},}, new Dictionary<Terminator, ReduceInformation>{ }, "856726d4-f9a1-4f6d-9123-fd9705bfafbd") },
		{ "f1143c4d-33c0-499e-ac5f-b7023f960c77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.VarParameter))}, }, "f1143c4d-33c0-499e-ac5f-b7023f960c77") },
		{ "945cc5d1-3dfd-4340-93d5-05be48c6e236", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "5033d099-8362-4f56-9e84-6791c2e4224f"}, { new Terminator(KeywordType.Integer), "4ae87c77-7c67-437a-a07a-d9b6788e7915"}, { new Terminator(KeywordType.Real), "e9aabef9-f8d1-4930-abd5-c3c627427e15"}, { new Terminator(KeywordType.Boolean), "233b639b-f59f-41eb-a3cc-3fe3277f8b26"}, { new Terminator(KeywordType.Character), "55ce1f63-2ebb-4eb9-b56a-2e979f3b7e72"},}, new Dictionary<Terminator, ReduceInformation>{ }, "945cc5d1-3dfd-4340-93d5-05be48c6e236") },
		{ "02c8ecbb-3ebd-4823-bd4b-a9ea517715e0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.SubprogramHead))}, }, "02c8ecbb-3ebd-4823-bd4b-a9ea517715e0") },
		{ "42d947ee-3a1a-4051-a8a2-9107628ba061", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Colon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.FormalParameter))}, }, "42d947ee-3a1a-4051-a8a2-9107628ba061") },
		{ "34dc47bb-22ab-45f2-b96a-c46f3b7bb32b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Of), "f319b09c-acb6-4194-ae6c-953a9f2e32da"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34dc47bb-22ab-45f2-b96a-c46f3b7bb32b") },
		{ "8c28c608-6ef0-4069-8e05-6a2f0a97ddb3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "3181b95d-e27e-4be4-aba6-ffc3766aae8c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8c28c608-6ef0-4069-8e05-6a2f0a97ddb3") },
		{ "fa3979f3-9012-408a-993e-b5f4d2a6c576", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "79c33cde-c5da-4352-a01e-28a3909cc170"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fa3979f3-9012-408a-993e-b5f4d2a6c576") },
		{ "f2c41046-68b5-4f2f-b52d-fad57c7da07e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "8ea4a486-4608-4895-857e-8b9b3975835c"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "f2c41046-68b5-4f2f-b52d-fad57c7da07e") },
		{ "9efe492a-8b5d-4177-998c-19f101f6a3fa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "3f7121de-2734-4e7c-93c4-343c12452ee9"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "9efe492a-8b5d-4177-998c-19f101f6a3fa") },
		{ "46ca7707-dc50-4ff1-9259-7bd864d9666e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "46ca7707-dc50-4ff1-9259-7bd864d9666e") },
		{ "ed4ac725-60b5-49fe-b9f3-955cba35f640", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "ed4ac725-60b5-49fe-b9f3-955cba35f640") },
		{ "e1122f6f-dbba-4384-90a3-fe7ae63302bd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "e1122f6f-dbba-4384-90a3-fe7ae63302bd") },
		{ "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "c4d6ca8a-0db5-44e6-8860-2c3c0fb4789e"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11") },
		{ "58d80663-e860-413b-8d28-0833007d4cf0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "a33b1034-e27a-431b-a209-dd31265e6894"}, { new NonTerminator(NonTerminatorType.IdVarPart), "23b167dd-79e2-47ef-a6a3-6e3224e3312c"}, { new Terminator(DelimiterType.LeftSquareBracket), "fb26d8fa-a458-46c5-833e-27883da9979b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "58d80663-e860-413b-8d28-0833007d4cf0") },
		{ "8a5ba85a-39c9-4a84-9919-6cf571eae251", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "c9bd36de-933c-4f16-a388-c006ba1926b5"}, { Terminator.NumberTerminator, "ed4ac725-60b5-49fe-b9f3-955cba35f640"}, { new NonTerminator(NonTerminatorType.Variable), "e1122f6f-dbba-4384-90a3-fe7ae63302bd"}, { new Terminator(DelimiterType.LeftParenthesis), "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11"}, { Terminator.IdentifierTerminator, "58d80663-e860-413b-8d28-0833007d4cf0"}, { new Terminator(KeywordType.Not), "8a5ba85a-39c9-4a84-9919-6cf571eae251"}, { new Terminator(OperatorType.Minus), "690c573f-5844-4d53-b011-a586179298d3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8a5ba85a-39c9-4a84-9919-6cf571eae251") },
		{ "690c573f-5844-4d53-b011-a586179298d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3fedb336-b4f3-4005-9975-27e2eedb5e62"}, { Terminator.NumberTerminator, "ed4ac725-60b5-49fe-b9f3-955cba35f640"}, { new NonTerminator(NonTerminatorType.Variable), "e1122f6f-dbba-4384-90a3-fe7ae63302bd"}, { new Terminator(DelimiterType.LeftParenthesis), "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11"}, { Terminator.IdentifierTerminator, "58d80663-e860-413b-8d28-0833007d4cf0"}, { new Terminator(KeywordType.Not), "8a5ba85a-39c9-4a84-9919-6cf571eae251"}, { new Terminator(OperatorType.Minus), "690c573f-5844-4d53-b011-a586179298d3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "690c573f-5844-4d53-b011-a586179298d3") },
		{ "6bd25941-410d-48ba-992d-3b4b3fa55244", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "95a45cb2-0595-4ebb-a74d-6b0640876e4c"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "6bd25941-410d-48ba-992d-3b4b3fa55244") },
		{ "025e3778-0c18-494c-b336-51d7ce62e08c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "025e3778-0c18-494c-b336-51d7ce62e08c") },
		{ "9074a52b-01fb-48d6-bf47-f0307ddf8e3d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "9074a52b-01fb-48d6-bf47-f0307ddf8e3d") },
		{ "42021cfa-b6cd-433e-99d6-2aa70c56d238", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "31111ac4-f0f7-48da-a4e6-5714cb6b051e"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "42021cfa-b6cd-433e-99d6-2aa70c56d238") },
		{ "803b51f4-e67d-4390-ae4e-1ba3f983cf01", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "44c362e3-74c9-4685-acbd-ebf2accc1f71"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "803b51f4-e67d-4390-ae4e-1ba3f983cf01") },
		{ "62d9e3d5-410f-4c77-a45c-cb7cea90473d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "62d9e3d5-410f-4c77-a45c-cb7cea90473d") },
		{ "03834caa-9dde-478e-8731-3e47b577ec37", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "c191d4db-4825-408e-8ff9-fb1d17482c01"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "03834caa-9dde-478e-8731-3e47b577ec37") },
		{ "ea6a8f39-394b-4186-962e-f355b741b702", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "73ec1778-6140-40b8-a6c6-31a479399b44"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ea6a8f39-394b-4186-962e-f355b741b702") },
		{ "cec14544-b322-4990-aab8-d76f4cca6c2b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "cec14544-b322-4990-aab8-d76f4cca6c2b") },
		{ "dcde47e7-5026-4dde-8dcc-770aec831f2b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "dcde47e7-5026-4dde-8dcc-770aec831f2b") },
		{ "b08c7e84-53a1-4b33-afe8-d6f8fd859cea", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "b08c7e84-53a1-4b33-afe8-d6f8fd859cea") },
		{ "1522aa0c-6cd9-4af1-90f2-a55063c69a31", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "f278be89-d566-4733-bd9e-b2a4ddc83480"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1522aa0c-6cd9-4af1-90f2-a55063c69a31") },
		{ "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "e187c105-4885-4563-84bb-29ea2f73edff"}, { new NonTerminator(NonTerminatorType.IdVarPart), "6f9bf470-f5c4-42e8-8508-41fa7b904b12"}, { new Terminator(DelimiterType.LeftSquareBracket), "5c4392d1-6723-4f20-a87a-f1fd6f0239ca"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f") },
		{ "e635cd65-0abb-40cf-808b-469b663ab818", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "15ffb36f-f9f1-46d7-90d9-18a02c9d6e1d"}, { Terminator.NumberTerminator, "dcde47e7-5026-4dde-8dcc-770aec831f2b"}, { new NonTerminator(NonTerminatorType.Variable), "b08c7e84-53a1-4b33-afe8-d6f8fd859cea"}, { new Terminator(DelimiterType.LeftParenthesis), "1522aa0c-6cd9-4af1-90f2-a55063c69a31"}, { Terminator.IdentifierTerminator, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f"}, { new Terminator(KeywordType.Not), "e635cd65-0abb-40cf-808b-469b663ab818"}, { new Terminator(OperatorType.Minus), "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e635cd65-0abb-40cf-808b-469b663ab818") },
		{ "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "d7b3d141-5d53-4be0-9617-3b0522a9a194"}, { Terminator.NumberTerminator, "dcde47e7-5026-4dde-8dcc-770aec831f2b"}, { new NonTerminator(NonTerminatorType.Variable), "b08c7e84-53a1-4b33-afe8-d6f8fd859cea"}, { new Terminator(DelimiterType.LeftParenthesis), "1522aa0c-6cd9-4af1-90f2-a55063c69a31"}, { Terminator.IdentifierTerminator, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f"}, { new Terminator(KeywordType.Not), "e635cd65-0abb-40cf-808b-469b663ab818"}, { new Terminator(OperatorType.Minus), "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99") },
		{ "edc2921d-abf6-4571-aec0-01079ab34025", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "1395300a-3abf-4fb9-84e8-0caabe5e770e"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "edc2921d-abf6-4571-aec0-01079ab34025") },
		{ "e66d9dfa-089d-4e43-a99e-90437e2ffbc5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "e66d9dfa-089d-4e43-a99e-90437e2ffbc5") },
		{ "444f758d-223e-4aa7-8998-ffd99c4c82f6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "444f758d-223e-4aa7-8998-ffd99c4c82f6") },
		{ "d81c17f7-e6b8-4a13-a6e1-6811d4714db8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f38cf778-16d3-4437-aae4-a9e3f5c14120"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d81c17f7-e6b8-4a13-a6e1-6811d4714db8") },
		{ "baa9f2b5-6f3e-47f1-810c-51abd07c0a6d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "39265046-c676-42af-8fc9-750de606aa0d"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "baa9f2b5-6f3e-47f1-810c-51abd07c0a6d") },
		{ "9f0f945f-012e-4508-943f-92f1ea0df9b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ExpressionList))}, }, "9f0f945f-012e-4508-943f-92f1ea0df9b8") },
		{ "fce83d48-f0d2-447d-b4c3-92d15ccb52f7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "11cdc5be-cd74-4b9b-a3c8-fbeef2e5b440"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "fce83d48-f0d2-447d-b4c3-92d15ccb52f7") },
		{ "e3af1577-3d2d-42fa-bbb3-a6fb17f72f55", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "5bd4c184-2120-4a07-b969-1471a23e107a"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "e3af1577-3d2d-42fa-bbb3-a6fb17f72f55") },
		{ "9e547003-1a39-4700-b2f6-53bb37c9856b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "9e547003-1a39-4700-b2f6-53bb37c9856b") },
		{ "54f6d5f8-1848-426c-a42e-4590d41f479a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "54f6d5f8-1848-426c-a42e-4590d41f479a") },
		{ "6a2b5f1f-8656-4115-9912-599704decbdd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "6a2b5f1f-8656-4115-9912-599704decbdd") },
		{ "0971f571-b443-455b-b18b-dea3b710286e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "01fb6a16-1fbb-47b3-b87c-9f89c65c444c"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0971f571-b443-455b-b18b-dea3b710286e") },
		{ "12530f8f-519d-475a-84a1-39ce3d90d01c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "bef8cb90-99b9-47a6-a845-c77f5377b302"}, { new NonTerminator(NonTerminatorType.IdVarPart), "eb9749a2-4e3d-4dd1-ba52-d4db09c24e1c"}, { new Terminator(DelimiterType.LeftSquareBracket), "8b7f1c05-8194-44d6-a9c6-7084135f653b"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "12530f8f-519d-475a-84a1-39ce3d90d01c") },
		{ "ebdd204c-a99b-4345-953b-d1d98f0c8f92", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "bccb6b96-243d-44f8-bd99-253df59b5ca3"}, { Terminator.NumberTerminator, "54f6d5f8-1848-426c-a42e-4590d41f479a"}, { new NonTerminator(NonTerminatorType.Variable), "6a2b5f1f-8656-4115-9912-599704decbdd"}, { new Terminator(DelimiterType.LeftParenthesis), "0971f571-b443-455b-b18b-dea3b710286e"}, { Terminator.IdentifierTerminator, "12530f8f-519d-475a-84a1-39ce3d90d01c"}, { new Terminator(KeywordType.Not), "ebdd204c-a99b-4345-953b-d1d98f0c8f92"}, { new Terminator(OperatorType.Minus), "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ebdd204c-a99b-4345-953b-d1d98f0c8f92") },
		{ "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3959483e-3ab1-4212-a428-75031426888f"}, { Terminator.NumberTerminator, "54f6d5f8-1848-426c-a42e-4590d41f479a"}, { new NonTerminator(NonTerminatorType.Variable), "6a2b5f1f-8656-4115-9912-599704decbdd"}, { new Terminator(DelimiterType.LeftParenthesis), "0971f571-b443-455b-b18b-dea3b710286e"}, { Terminator.IdentifierTerminator, "12530f8f-519d-475a-84a1-39ce3d90d01c"}, { new Terminator(KeywordType.Not), "ebdd204c-a99b-4345-953b-d1d98f0c8f92"}, { new Terminator(OperatorType.Minus), "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1") },
		{ "ea42ea44-f610-4828-bfd6-000d11a1bf30", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "8f9af640-1f9d-45fa-a72f-81aeb455202d"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ea42ea44-f610-4828-bfd6-000d11a1bf30") },
		{ "1a16deba-c813-4ed4-818f-b9433f4b1919", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "1a16deba-c813-4ed4-818f-b9433f4b1919") },
		{ "7a7cf14b-9abf-4f6a-839e-7e77491e4186", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "7a7cf14b-9abf-4f6a-839e-7e77491e4186") },
		{ "f6834c8a-02b1-4ca4-ba9a-43a75cf9f946", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "37e559cd-577e-4292-b790-1c2f884f201e"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f6834c8a-02b1-4ca4-ba9a-43a75cf9f946") },
		{ "0960586b-bf2a-46d3-8d31-3d8f167c4f09", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "969ac179-6d13-4d58-bccd-ecc85afd8110"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0960586b-bf2a-46d3-8d31-3d8f167c4f09") },
		{ "52c6efd4-5584-4857-8971-f4118744fad4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "52c6efd4-5584-4857-8971-f4118744fad4") },
		{ "93cd56b4-f8f5-460b-890f-c9502f3e008b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "e7bf7a64-c59d-4f69-a585-83e24d77abb6"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "93cd56b4-f8f5-460b-890f-c9502f3e008b") },
		{ "43ed09a8-4d0e-4002-b556-a3631bb81a70", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "238b4525-1f93-4533-a0f4-f46f6f78d68b"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5931ff93-851c-45ec-9423-08a21d8e2094"}, { new NonTerminator(NonTerminatorType.Term), "d34e7eb0-5902-4736-8500-5fc2b5ffdeb3"}, { new NonTerminator(NonTerminatorType.Factor), "4ffc7b40-22bd-4d00-b236-1ecdc33d1c1c"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "43ed09a8-4d0e-4002-b556-a3631bb81a70") },
		{ "af941e16-1c67-40cc-a850-2601bb91e263", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "0c3523a8-4c7c-4476-99b8-12c478f86450"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "5931ff93-851c-45ec-9423-08a21d8e2094"}, { new NonTerminator(NonTerminatorType.Term), "d34e7eb0-5902-4736-8500-5fc2b5ffdeb3"}, { new NonTerminator(NonTerminatorType.Factor), "4ffc7b40-22bd-4d00-b236-1ecdc33d1c1c"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "af941e16-1c67-40cc-a850-2601bb91e263") },
		{ "a940fded-52ac-4e52-ab7f-f017a3423e33", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2e0422e7-95d8-483c-9b8a-1a16c3587f2e"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a940fded-52ac-4e52-ab7f-f017a3423e33") },
		{ "9a14aa6b-8e41-4d84-9f03-e4d7bee4336a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Then), "9e06bacd-72ec-4d22-aeac-5b6f745e563d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9a14aa6b-8e41-4d84-9f03-e4d7bee4336a") },
		{ "3634204b-806f-4052-a632-0d6ec9c36159", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(OperatorType.Assign), "e3a0af75-b758-4083-aa0e-2dfc438b010d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3634204b-806f-4052-a632-0d6ec9c36159") },
		{ "c780ec8e-bd81-474f-879a-d9549651cf13", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "34041fb1-b176-4380-bb66-6fef3c383e6b"}, { new Terminator(DelimiterType.Semicolon), "fad9faa7-530f-483a-8fae-ecc0e45f8c81"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c780ec8e-bd81-474f-879a-d9549651cf13") },
		{ "12e2617c-b7c2-4daf-a413-343130aa70fc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "580061df-943b-4f1d-8670-39025d12b7ba"}, { new NonTerminator(NonTerminatorType.Factor), "83ffeb68-ea6d-4577-8175-80014c07c5ec"}, { Terminator.NumberTerminator, "9a5d3e85-90c6-487a-bf96-172efedb856a"}, { new NonTerminator(NonTerminatorType.Variable), "fc5d3570-ef84-49c0-8351-2db09f504e50"}, { new Terminator(DelimiterType.LeftParenthesis), "69ace23c-8c28-471e-91ac-21a82cffafa9"}, { Terminator.IdentifierTerminator, "3292a333-3a9a-4a7f-913d-66352cd05e41"}, { new Terminator(KeywordType.Not), "519bf42f-444f-42bf-a6d1-5e8fdbbba37c"}, { new Terminator(OperatorType.Minus), "41e1690e-37ab-43a5-9a15-c546e9726ebd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "12e2617c-b7c2-4daf-a413-343130aa70fc") },
		{ "e946d7cc-37cd-4257-ac3e-d4370582363c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "afc459be-35b8-4cf2-b1f1-ea883fdeee7f"}, { Terminator.NumberTerminator, "9a5d3e85-90c6-487a-bf96-172efedb856a"}, { new NonTerminator(NonTerminatorType.Variable), "fc5d3570-ef84-49c0-8351-2db09f504e50"}, { new Terminator(DelimiterType.LeftParenthesis), "69ace23c-8c28-471e-91ac-21a82cffafa9"}, { Terminator.IdentifierTerminator, "3292a333-3a9a-4a7f-913d-66352cd05e41"}, { new Terminator(KeywordType.Not), "519bf42f-444f-42bf-a6d1-5e8fdbbba37c"}, { new Terminator(OperatorType.Minus), "41e1690e-37ab-43a5-9a15-c546e9726ebd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e946d7cc-37cd-4257-ac3e-d4370582363c") },
		{ "e3c8ec34-e9b4-416b-a18b-cda2a1152579", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "96438cb0-4853-48c5-9659-9cb05cf4f876"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e3c8ec34-e9b4-416b-a18b-cda2a1152579") },
		{ "e3d09693-d886-41b9-8522-f17e7c3e734b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "cb3ef9ea-8782-4d3d-ad6c-c3981ab64316"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e3d09693-d886-41b9-8522-f17e7c3e734b") },
		{ "b1be5327-1efb-46b9-8fd7-a2bcac46fc19", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "b1be5327-1efb-46b9-8fd7-a2bcac46fc19") },
		{ "508985e2-1249-47a8-8a9a-3eeea359c0bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "345904d3-dc04-408b-8fdd-b2f40a28fbe5"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "508985e2-1249-47a8-8a9a-3eeea359c0bf") },
		{ "6cac59ea-14f3-42e6-9e14-d18399ff8a79", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "6cac59ea-14f3-42e6-9e14-d18399ff8a79") },
		{ "449d55ac-3419-4930-b49a-a203f0aca2fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "449d55ac-3419-4930-b49a-a203f0aca2fe") },
		{ "e4a94a94-9eab-423d-a565-bf04c6f376ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "66c46f73-e20e-45e2-8801-4ed96a7bc952"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "e4a94a94-9eab-423d-a565-bf04c6f376ff") },
		{ "6c614134-d955-4933-98d0-97cc4495f5ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "b1549687-fbab-42f0-9580-f9d0feb4fe0a"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "6c614134-d955-4933-98d0-97cc4495f5ff") },
		{ "646cc8a8-35dd-4ff8-a73e-85e67e40d7c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "646cc8a8-35dd-4ff8-a73e-85e67e40d7c4") },
		{ "1c6b5b11-61f1-4492-8643-31a607b93b10", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "1c6b5b11-61f1-4492-8643-31a607b93b10") },
		{ "1d17afa8-ed2c-4699-80ff-93e750e13e01", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "1d17afa8-ed2c-4699-80ff-93e750e13e01") },
		{ "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "d3001315-dde8-42cf-b16c-0b81d069b067"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3") },
		{ "57310d2d-d905-455e-b7a4-2885e02e8a69", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "b0971def-6ac4-4289-98ab-93df9c8bd779"}, { new NonTerminator(NonTerminatorType.IdVarPart), "7752a580-a103-42f5-9836-4429d71a75a1"}, { new Terminator(DelimiterType.LeftSquareBracket), "34fa6dc2-8f4a-4db5-a9af-56b1d879329e"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "57310d2d-d905-455e-b7a4-2885e02e8a69") },
		{ "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "17476109-cfcf-4ead-b91d-cfb53160c2b4"}, { Terminator.NumberTerminator, "1c6b5b11-61f1-4492-8643-31a607b93b10"}, { new NonTerminator(NonTerminatorType.Variable), "1d17afa8-ed2c-4699-80ff-93e750e13e01"}, { new Terminator(DelimiterType.LeftParenthesis), "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3"}, { Terminator.IdentifierTerminator, "57310d2d-d905-455e-b7a4-2885e02e8a69"}, { new Terminator(KeywordType.Not), "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79"}, { new Terminator(OperatorType.Minus), "60a6366e-a4e6-4156-8dd7-c075e1384341"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79") },
		{ "60a6366e-a4e6-4156-8dd7-c075e1384341", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f2fd6b9d-e9ab-4cbc-9716-1c9e3c3d087d"}, { Terminator.NumberTerminator, "1c6b5b11-61f1-4492-8643-31a607b93b10"}, { new NonTerminator(NonTerminatorType.Variable), "1d17afa8-ed2c-4699-80ff-93e750e13e01"}, { new Terminator(DelimiterType.LeftParenthesis), "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3"}, { Terminator.IdentifierTerminator, "57310d2d-d905-455e-b7a4-2885e02e8a69"}, { new Terminator(KeywordType.Not), "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79"}, { new Terminator(OperatorType.Minus), "60a6366e-a4e6-4156-8dd7-c075e1384341"},}, new Dictionary<Terminator, ReduceInformation>{ }, "60a6366e-a4e6-4156-8dd7-c075e1384341") },
		{ "238e0ad3-d0af-4875-b450-91429f43152b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "60e3a830-2cc0-4e3e-a30c-38d6a442c522"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "238e0ad3-d0af-4875-b450-91429f43152b") },
		{ "3528c660-9c13-431d-bc41-ca80a4996990", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "3528c660-9c13-431d-bc41-ca80a4996990") },
		{ "7de92191-392b-48e8-aede-91997c3c3be2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "7de92191-392b-48e8-aede-91997c3c3be2") },
		{ "fc32330f-a598-4838-b072-0b7486ae7a31", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "b77acdf9-1917-466f-9f70-b3f82a478dd3"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fc32330f-a598-4838-b072-0b7486ae7a31") },
		{ "cb154a33-ed16-4fbd-82f4-c20a8c1719a3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "cbd53b68-80f4-4b36-ac19-27c535320741"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cb154a33-ed16-4fbd-82f4-c20a8c1719a3") },
		{ "a5fd6c1f-67b2-4d6d-951a-7c9edd4f720d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "a5fd6c1f-67b2-4d6d-951a-7c9edd4f720d") },
		{ "2cf5715d-fac8-4eb2-be9c-5a4a4e6948ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "2cf5715d-fac8-4eb2-be9c-5a4a4e6948ec") },
		{ "644edcd6-0236-4a6b-a3cb-767f02323eb9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "636aa0a9-22e6-450b-97f0-d0f744401617"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "d082188f-95b4-491e-9845-6333f9b77539"}, { new NonTerminator(NonTerminatorType.Term), "19275939-5968-41ff-a0e8-8accfd4f613e"}, { new NonTerminator(NonTerminatorType.Factor), "fa4afd19-9028-416d-8819-5013cebf7f6c"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "644edcd6-0236-4a6b-a3cb-767f02323eb9") },
		{ "a60c8f40-677e-412d-aeac-a071dd69570a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "de4da83e-68c1-485a-aa8f-777d20322c89"}, { new NonTerminator(NonTerminatorType.Term), "2d453576-f044-48bf-a32d-014f99260626"}, { new NonTerminator(NonTerminatorType.Factor), "8d4a4043-8902-4b16-9656-3e08535bcd6b"}, { Terminator.NumberTerminator, "82459506-5865-4869-9748-1548327e336c"}, { new NonTerminator(NonTerminatorType.Variable), "94e0d4f8-3c2a-4375-b155-eafda749452b"}, { new Terminator(DelimiterType.LeftParenthesis), "7e73c05f-d045-43d1-8a27-847dd891b9a5"}, { Terminator.IdentifierTerminator, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf"}, { new Terminator(KeywordType.Not), "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f"}, { new Terminator(OperatorType.Minus), "f735189a-e838-4e6b-a3a6-19fa8a01364d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a60c8f40-677e-412d-aeac-a071dd69570a") },
		{ "16d42ef1-b371-4fbc-b1bb-f15cfad159b5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "949cd87d-14c5-4642-9302-ca0bf1e13dbd"}, { new NonTerminator(NonTerminatorType.Factor), "a1220313-359c-4239-94ef-09d472d79efc"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "16d42ef1-b371-4fbc-b1bb-f15cfad159b5") },
		{ "88f40435-da28-4970-a1a5-87cd18d4b8c0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "113ede1c-8d70-4d88-a9a3-578286dc8d47"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "88f40435-da28-4970-a1a5-87cd18d4b8c0") },
		{ "69334b04-7159-4ad1-a966-80f80cb69461", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "de56ce99-616d-4a00-9779-c36f636ed54e"},}, new Dictionary<Terminator, ReduceInformation>{ }, "69334b04-7159-4ad1-a966-80f80cb69461") },
		{ "1ede02b4-3fcf-4f76-9950-94ad8a0467b7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "75e68f1f-9f89-4756-b31e-31632f9bb9b8"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1ede02b4-3fcf-4f76-9950-94ad8a0467b7") },
		{ "bcc1a319-703d-4eab-ac8a-8326de81a307", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "bcc1a319-703d-4eab-ac8a-8326de81a307") },
		{ "33879ee8-9a89-405e-959c-ca66d26266e1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "57880f16-f23e-4043-8ebb-d3d7c7a7ea2c"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "33879ee8-9a89-405e-959c-ca66d26266e1") },
		{ "db82a94f-eac4-4b64-a618-ae251c9f80e9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "db82a94f-eac4-4b64-a618-ae251c9f80e9") },
		{ "c5dbc2ef-4d81-45c7-92b8-9044ed6bc177", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "c5dbc2ef-4d81-45c7-92b8-9044ed6bc177") },
		{ "daf43aea-5fa8-4ace-96de-f620c2749bd4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.End), "341eb8f9-91a7-4d43-91bf-76624dc6f9e1"}, { new Terminator(DelimiterType.Semicolon), "fad9faa7-530f-483a-8fae-ecc0e45f8c81"},}, new Dictionary<Terminator, ReduceInformation>{ }, "daf43aea-5fa8-4ace-96de-f620c2749bd4") },
		{ "6d68dd4b-5efb-4b7d-a4c6-2beab31e0d82", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ParameterList))}, }, "6d68dd4b-5efb-4b7d-a4c6-2beab31e0d82") },
		{ "5033d099-8362-4f56-9e84-6791c2e4224f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.ValueParameter))}, }, "5033d099-8362-4f56-9e84-6791c2e4224f") },
		{ "4ae87c77-7c67-437a-a07a-d9b6788e7915", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "4ae87c77-7c67-437a-a07a-d9b6788e7915") },
		{ "e9aabef9-f8d1-4930-abd5-c3c627427e15", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "e9aabef9-f8d1-4930-abd5-c3c627427e15") },
		{ "233b639b-f59f-41eb-a3cc-3fe3277f8b26", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "233b639b-f59f-41eb-a3cc-3fe3277f8b26") },
		{ "55ce1f63-2ebb-4eb9-b56a-2e979f3b7e72", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.BasicType))}, }, "55ce1f63-2ebb-4eb9-b56a-2e979f3b7e72") },
		{ "f319b09c-acb6-4194-ae6c-953a9f2e32da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.BasicType), "7dc5dce4-78d8-4518-b196-4576d0237afe"}, { new Terminator(KeywordType.Integer), "af867cb8-3fd0-40d2-93ed-821588536cd6"}, { new Terminator(KeywordType.Real), "1cf38e3d-a786-4ca3-8ca0-f41ed1e52498"}, { new Terminator(KeywordType.Boolean), "e7f508c2-f944-4a52-82c9-2c1da660b58e"}, { new Terminator(KeywordType.Character), "50dac50a-0c16-462e-934c-bcce04c19b99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f319b09c-acb6-4194-ae6c-953a9f2e32da") },
		{ "3181b95d-e27e-4be4-aba6-ffc3766aae8c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.DoubleDots), "748e76e8-e3c3-46c5-8c77-daf70036acda"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3181b95d-e27e-4be4-aba6-ffc3766aae8c") },
		{ "79c33cde-c5da-4352-a01e-28a3909cc170", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Period))}, }, "79c33cde-c5da-4352-a01e-28a3909cc170") },
		{ "8ea4a486-4608-4895-857e-8b9b3975835c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "ee1eb23d-ad22-4acd-a847-54e6d30ad6ba"}, { new NonTerminator(NonTerminatorType.Factor), "46ca7707-dc50-4ff1-9259-7bd864d9666e"}, { Terminator.NumberTerminator, "ed4ac725-60b5-49fe-b9f3-955cba35f640"}, { new NonTerminator(NonTerminatorType.Variable), "e1122f6f-dbba-4384-90a3-fe7ae63302bd"}, { new Terminator(DelimiterType.LeftParenthesis), "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11"}, { Terminator.IdentifierTerminator, "58d80663-e860-413b-8d28-0833007d4cf0"}, { new Terminator(KeywordType.Not), "8a5ba85a-39c9-4a84-9919-6cf571eae251"}, { new Terminator(OperatorType.Minus), "690c573f-5844-4d53-b011-a586179298d3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8ea4a486-4608-4895-857e-8b9b3975835c") },
		{ "3f7121de-2734-4e7c-93c4-343c12452ee9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "50925b30-cd16-47d2-8034-f787d2eefe23"}, { Terminator.NumberTerminator, "ed4ac725-60b5-49fe-b9f3-955cba35f640"}, { new NonTerminator(NonTerminatorType.Variable), "e1122f6f-dbba-4384-90a3-fe7ae63302bd"}, { new Terminator(DelimiterType.LeftParenthesis), "4c3e9c92-38df-4212-a3c8-bf2bdd7c9f11"}, { Terminator.IdentifierTerminator, "58d80663-e860-413b-8d28-0833007d4cf0"}, { new Terminator(KeywordType.Not), "8a5ba85a-39c9-4a84-9919-6cf571eae251"}, { new Terminator(OperatorType.Minus), "690c573f-5844-4d53-b011-a586179298d3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3f7121de-2734-4e7c-93c4-343c12452ee9") },
		{ "c4d6ca8a-0db5-44e6-8860-2c3c0fb4789e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "2ddfe3fb-3841-4d32-9977-76f8ee1dd9d1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c4d6ca8a-0db5-44e6-8860-2c3c0fb4789e") },
		{ "a33b1034-e27a-431b-a209-dd31265e6894", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "dca691fe-380f-4761-b8b8-e16112947759"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a33b1034-e27a-431b-a209-dd31265e6894") },
		{ "23b167dd-79e2-47ef-a6a3-6e3224e3312c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "23b167dd-79e2-47ef-a6a3-6e3224e3312c") },
		{ "fb26d8fa-a458-46c5-833e-27883da9979b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "67f79d7c-7642-4211-a456-dac1ea29ae7b"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fb26d8fa-a458-46c5-833e-27883da9979b") },
		{ "c9bd36de-933c-4f16-a388-c006ba1926b5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "c9bd36de-933c-4f16-a388-c006ba1926b5") },
		{ "3fedb336-b4f3-4005-9975-27e2eedb5e62", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3fedb336-b4f3-4005-9975-27e2eedb5e62") },
		{ "31111ac4-f0f7-48da-a4e6-5714cb6b051e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "31111ac4-f0f7-48da-a4e6-5714cb6b051e") },
		{ "44c362e3-74c9-4685-acbd-ebf2accc1f71", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "44c362e3-74c9-4685-acbd-ebf2accc1f71") },
		{ "c191d4db-4825-408e-8ff9-fb1d17482c01", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "3774c848-d656-4b2b-895a-538ce52b81a5"}, { new NonTerminator(NonTerminatorType.Factor), "cec14544-b322-4990-aab8-d76f4cca6c2b"}, { Terminator.NumberTerminator, "dcde47e7-5026-4dde-8dcc-770aec831f2b"}, { new NonTerminator(NonTerminatorType.Variable), "b08c7e84-53a1-4b33-afe8-d6f8fd859cea"}, { new Terminator(DelimiterType.LeftParenthesis), "1522aa0c-6cd9-4af1-90f2-a55063c69a31"}, { Terminator.IdentifierTerminator, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f"}, { new Terminator(KeywordType.Not), "e635cd65-0abb-40cf-808b-469b663ab818"}, { new Terminator(OperatorType.Minus), "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c191d4db-4825-408e-8ff9-fb1d17482c01") },
		{ "73ec1778-6140-40b8-a6c6-31a479399b44", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3f9f12ab-92e6-41ab-ae33-2baad2eeca43"}, { Terminator.NumberTerminator, "dcde47e7-5026-4dde-8dcc-770aec831f2b"}, { new NonTerminator(NonTerminatorType.Variable), "b08c7e84-53a1-4b33-afe8-d6f8fd859cea"}, { new Terminator(DelimiterType.LeftParenthesis), "1522aa0c-6cd9-4af1-90f2-a55063c69a31"}, { Terminator.IdentifierTerminator, "c4471a4c-7e3d-4a40-b62e-dbf6b6257d2f"}, { new Terminator(KeywordType.Not), "e635cd65-0abb-40cf-808b-469b663ab818"}, { new Terminator(OperatorType.Minus), "dffd2f9f-3023-4b1c-b3c9-aa9652c27f99"},}, new Dictionary<Terminator, ReduceInformation>{ }, "73ec1778-6140-40b8-a6c6-31a479399b44") },
		{ "f278be89-d566-4733-bd9e-b2a4ddc83480", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "7f0cd7ff-0090-4c8c-ba73-6cc2b0a843bd"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f278be89-d566-4733-bd9e-b2a4ddc83480") },
		{ "e187c105-4885-4563-84bb-29ea2f73edff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "5e1ac291-b1e3-4d25-a4f1-84545e97cc53"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e187c105-4885-4563-84bb-29ea2f73edff") },
		{ "6f9bf470-f5c4-42e8-8508-41fa7b904b12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "6f9bf470-f5c4-42e8-8508-41fa7b904b12") },
		{ "5c4392d1-6723-4f20-a87a-f1fd6f0239ca", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "0cd0fa56-1f9e-4a4d-97aa-300f0d78a1da"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5c4392d1-6723-4f20-a87a-f1fd6f0239ca") },
		{ "15ffb36f-f9f1-46d7-90d9-18a02c9d6e1d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "15ffb36f-f9f1-46d7-90d9-18a02c9d6e1d") },
		{ "d7b3d141-5d53-4be0-9617-3b0522a9a194", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "d7b3d141-5d53-4be0-9617-3b0522a9a194") },
		{ "f38cf778-16d3-4437-aae4-a9e3f5c14120", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "f38cf778-16d3-4437-aae4-a9e3f5c14120") },
		{ "39265046-c676-42af-8fc9-750de606aa0d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "39265046-c676-42af-8fc9-750de606aa0d") },
		{ "11cdc5be-cd74-4b9b-a3c8-fbeef2e5b440", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "07a4a59e-f4a5-4740-8cfb-1973f74a7d7f"}, { new NonTerminator(NonTerminatorType.Factor), "9e547003-1a39-4700-b2f6-53bb37c9856b"}, { Terminator.NumberTerminator, "54f6d5f8-1848-426c-a42e-4590d41f479a"}, { new NonTerminator(NonTerminatorType.Variable), "6a2b5f1f-8656-4115-9912-599704decbdd"}, { new Terminator(DelimiterType.LeftParenthesis), "0971f571-b443-455b-b18b-dea3b710286e"}, { Terminator.IdentifierTerminator, "12530f8f-519d-475a-84a1-39ce3d90d01c"}, { new Terminator(KeywordType.Not), "ebdd204c-a99b-4345-953b-d1d98f0c8f92"}, { new Terminator(OperatorType.Minus), "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "11cdc5be-cd74-4b9b-a3c8-fbeef2e5b440") },
		{ "5bd4c184-2120-4a07-b969-1471a23e107a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "3870ab24-1c1b-4cb9-bcf5-16d5772e0c04"}, { Terminator.NumberTerminator, "54f6d5f8-1848-426c-a42e-4590d41f479a"}, { new NonTerminator(NonTerminatorType.Variable), "6a2b5f1f-8656-4115-9912-599704decbdd"}, { new Terminator(DelimiterType.LeftParenthesis), "0971f571-b443-455b-b18b-dea3b710286e"}, { Terminator.IdentifierTerminator, "12530f8f-519d-475a-84a1-39ce3d90d01c"}, { new Terminator(KeywordType.Not), "ebdd204c-a99b-4345-953b-d1d98f0c8f92"}, { new Terminator(OperatorType.Minus), "35c6510f-1f3c-4e63-ad31-1c8c5bf489f1"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5bd4c184-2120-4a07-b969-1471a23e107a") },
		{ "01fb6a16-1fbb-47b3-b87c-9f89c65c444c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "69ff5341-5730-4c85-841e-202da5145b86"},}, new Dictionary<Terminator, ReduceInformation>{ }, "01fb6a16-1fbb-47b3-b87c-9f89c65c444c") },
		{ "bef8cb90-99b9-47a6-a845-c77f5377b302", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "2b2a99ad-249d-4a1c-986b-18aec7474217"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "bef8cb90-99b9-47a6-a845-c77f5377b302") },
		{ "eb9749a2-4e3d-4dd1-ba52-d4db09c24e1c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "eb9749a2-4e3d-4dd1-ba52-d4db09c24e1c") },
		{ "8b7f1c05-8194-44d6-a9c6-7084135f653b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "dff5f159-57ae-4ec6-800a-593e96505232"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8b7f1c05-8194-44d6-a9c6-7084135f653b") },
		{ "bccb6b96-243d-44f8-bd99-253df59b5ca3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "bccb6b96-243d-44f8-bd99-253df59b5ca3") },
		{ "3959483e-3ab1-4212-a428-75031426888f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "3959483e-3ab1-4212-a428-75031426888f") },
		{ "37e559cd-577e-4292-b790-1c2f884f201e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "37e559cd-577e-4292-b790-1c2f884f201e") },
		{ "969ac179-6d13-4d58-bccd-ecc85afd8110", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "969ac179-6d13-4d58-bccd-ecc85afd8110") },
		{ "e7bf7a64-c59d-4f69-a585-83e24d77abb6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "e7bf7a64-c59d-4f69-a585-83e24d77abb6") },
		{ "238b4525-1f93-4533-a0f4-f46f6f78d68b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "238b4525-1f93-4533-a0f4-f46f6f78d68b") },
		{ "5931ff93-851c-45ec-9423-08a21d8e2094", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "597d8f5a-fb3f-4431-a0df-ed5b93bd712e"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "53c766c4-cb3c-4808-87ba-ec83b70b7144"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "5931ff93-851c-45ec-9423-08a21d8e2094") },
		{ "d34e7eb0-5902-4736-8500-5fc2b5ffdeb3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d2d8ac0a-cee5-44a1-88b2-a0c7ebffd9fa"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "d34e7eb0-5902-4736-8500-5fc2b5ffdeb3") },
		{ "4ffc7b40-22bd-4d00-b236-1ecdc33d1c1c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "4ffc7b40-22bd-4d00-b236-1ecdc33d1c1c") },
		{ "f9d05b12-aa8a-418a-a630-145d75458c2c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "f9d05b12-aa8a-418a-a630-145d75458c2c") },
		{ "3a8f090b-7000-422e-a337-8a47e0dc41eb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "3a8f090b-7000-422e-a337-8a47e0dc41eb") },
		{ "0e578da4-76c7-41d0-a78a-0ce8c05adb66", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "0a0a04c9-c469-4ed4-b51a-ebb5379e4aff"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0e578da4-76c7-41d0-a78a-0ce8c05adb66") },
		{ "dad662a6-c5db-45e5-895c-7a67e47b112f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "420603e3-e3fa-4260-91a2-6561c6b96611"}, { new NonTerminator(NonTerminatorType.IdVarPart), "753d5934-6a29-472d-b16d-b48b1fd9ac9f"}, { new Terminator(DelimiterType.LeftSquareBracket), "c0c1418b-c359-49ed-aca5-57cec34933ff"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "dad662a6-c5db-45e5-895c-7a67e47b112f") },
		{ "320e1a39-5998-4a56-8921-c8342b376d6c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "f7dad62f-ebe7-408c-a151-eb4e54c6e2c6"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "320e1a39-5998-4a56-8921-c8342b376d6c") },
		{ "b3dc7239-be51-44f7-b53a-dfc19b1999e3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "b62a7a70-e2ba-4784-a59e-a770d6a614ec"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b3dc7239-be51-44f7-b53a-dfc19b1999e3") },
		{ "0c3523a8-4c7c-4476-99b8-12c478f86450", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Statement))}, }, "0c3523a8-4c7c-4476-99b8-12c478f86450") },
		{ "2e0422e7-95d8-483c-9b8a-1a16c3587f2e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "e5b45ea3-1526-4f13-af6f-1a8f84c9a3ad"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2e0422e7-95d8-483c-9b8a-1a16c3587f2e") },
		{ "9e06bacd-72ec-4d22-aeac-5b6f745e563d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "714345e7-8f29-4690-8a90-f5d56fa2c264"}, { new NonTerminator(NonTerminatorType.Variable), "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1"}, { Terminator.IdentifierTerminator, "0375bfdc-70d2-4173-820c-c00295879eb4"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "1166a74d-cd84-447a-884e-6e994b426865"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "35103497-0e41-4976-8eaf-a6784e27cad6"}, { new Terminator(KeywordType.If), "158f9f5f-b96c-400b-aea4-d420cac1e1f5"}, { new Terminator(KeywordType.For), "e5eae017-43f9-43a5-8cc6-b467d75a7d5d"}, { new Terminator(KeywordType.Begin), "5342eece-10e0-4678-9b11-0dfece0a51b4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "9e06bacd-72ec-4d22-aeac-5b6f745e563d") },
		{ "e3a0af75-b758-4083-aa0e-2dfc438b010d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "7a994450-b976-49e3-abfe-b93b77e25d77"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "c627f7e8-db78-474b-ae8a-676215a5cd02"}, { new NonTerminator(NonTerminatorType.Term), "3410b4c1-8faf-45a4-b48d-636916e1a449"}, { new NonTerminator(NonTerminatorType.Factor), "a1220313-359c-4239-94ef-09d472d79efc"}, { Terminator.NumberTerminator, "c41f9918-370e-4391-bdb2-9ef02b7ee506"}, { new NonTerminator(NonTerminatorType.Variable), "a3380aa2-039f-4429-87f5-d1a103a15949"}, { new Terminator(DelimiterType.LeftParenthesis), "e6abce5f-c2bd-40ec-b2d8-6723b714ed6b"}, { Terminator.IdentifierTerminator, "4ea9d59e-2f9a-4470-9f73-ec86a1242e06"}, { new Terminator(KeywordType.Not), "5dc3e7c2-05c5-4f56-a41e-9d92b72c63cf"}, { new Terminator(OperatorType.Minus), "8991e6dd-a23f-4139-970e-febccdbb3396"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e3a0af75-b758-4083-aa0e-2dfc438b010d") },
		{ "34041fb1-b176-4380-bb66-6fef3c383e6b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "34041fb1-b176-4380-bb66-6fef3c383e6b") },
		{ "580061df-943b-4f1d-8670-39025d12b7ba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "e946d7cc-37cd-4257-ac3e-d4370582363c"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "580061df-943b-4f1d-8670-39025d12b7ba") },
		{ "afc459be-35b8-4cf2-b1f1-ea883fdeee7f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "afc459be-35b8-4cf2-b1f1-ea883fdeee7f") },
		{ "96438cb0-4853-48c5-9659-9cb05cf4f876", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "96438cb0-4853-48c5-9659-9cb05cf4f876") },
		{ "cb3ef9ea-8782-4d3d-ad6c-c3981ab64316", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8c321601-bb8b-49d9-acff-e02c1256ee75"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "cb3ef9ea-8782-4d3d-ad6c-c3981ab64316") },
		{ "345904d3-dc04-408b-8fdd-b2f40a28fbe5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "9378afe3-f928-417f-8e16-bd369c2cc1be"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "345904d3-dc04-408b-8fdd-b2f40a28fbe5") },
		{ "66c46f73-e20e-45e2-8801-4ed96a7bc952", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "b5035c5a-f649-4dd9-951f-aa10202bc183"}, { new NonTerminator(NonTerminatorType.Factor), "646cc8a8-35dd-4ff8-a73e-85e67e40d7c4"}, { Terminator.NumberTerminator, "1c6b5b11-61f1-4492-8643-31a607b93b10"}, { new NonTerminator(NonTerminatorType.Variable), "1d17afa8-ed2c-4699-80ff-93e750e13e01"}, { new Terminator(DelimiterType.LeftParenthesis), "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3"}, { Terminator.IdentifierTerminator, "57310d2d-d905-455e-b7a4-2885e02e8a69"}, { new Terminator(KeywordType.Not), "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79"}, { new Terminator(OperatorType.Minus), "60a6366e-a4e6-4156-8dd7-c075e1384341"},}, new Dictionary<Terminator, ReduceInformation>{ }, "66c46f73-e20e-45e2-8801-4ed96a7bc952") },
		{ "b1549687-fbab-42f0-9580-f9d0feb4fe0a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "fff24872-d37f-4365-9cef-dff7ca60914d"}, { Terminator.NumberTerminator, "1c6b5b11-61f1-4492-8643-31a607b93b10"}, { new NonTerminator(NonTerminatorType.Variable), "1d17afa8-ed2c-4699-80ff-93e750e13e01"}, { new Terminator(DelimiterType.LeftParenthesis), "3a4892bb-3b0e-4889-9ac2-b34fd0c29ae3"}, { Terminator.IdentifierTerminator, "57310d2d-d905-455e-b7a4-2885e02e8a69"}, { new Terminator(KeywordType.Not), "8a4a25cd-74bc-4b11-ae59-e3fa4c76ff79"}, { new Terminator(OperatorType.Minus), "60a6366e-a4e6-4156-8dd7-c075e1384341"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b1549687-fbab-42f0-9580-f9d0feb4fe0a") },
		{ "d3001315-dde8-42cf-b16c-0b81d069b067", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "0ae6b8f8-60dc-4654-b374-a13c54b7fc63"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d3001315-dde8-42cf-b16c-0b81d069b067") },
		{ "b0971def-6ac4-4289-98ab-93df9c8bd779", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "a786b8e5-e322-4fcf-b4f4-b0b353554608"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b0971def-6ac4-4289-98ab-93df9c8bd779") },
		{ "7752a580-a103-42f5-9836-4429d71a75a1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "7752a580-a103-42f5-9836-4429d71a75a1") },
		{ "34fa6dc2-8f4a-4db5-a9af-56b1d879329e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "9e93f16f-d7ca-439a-9ef0-ea91ffad7fa8"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "34fa6dc2-8f4a-4db5-a9af-56b1d879329e") },
		{ "17476109-cfcf-4ead-b91d-cfb53160c2b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "17476109-cfcf-4ead-b91d-cfb53160c2b4") },
		{ "f2fd6b9d-e9ab-4cbc-9716-1c9e3c3d087d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "f2fd6b9d-e9ab-4cbc-9716-1c9e3c3d087d") },
		{ "b77acdf9-1917-466f-9f70-b3f82a478dd3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "b77acdf9-1917-466f-9f70-b3f82a478dd3") },
		{ "cbd53b68-80f4-4b36-ac19-27c535320741", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "cbd53b68-80f4-4b36-ac19-27c535320741") },
		{ "636aa0a9-22e6-450b-97f0-d0f744401617", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "94142f12-aeb9-4b28-ba6e-d4b2da3fe7d8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "636aa0a9-22e6-450b-97f0-d0f744401617") },
		{ "d082188f-95b4-491e-9845-6333f9b77539", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.RelationOperator), "14274100-02ac-49b9-9ecf-56feb757d9b0"}, { new Terminator(OperatorType.Equal), "687ec427-3947-4e5c-8d56-37456f7c831b"}, { new Terminator(OperatorType.NotEqual), "ae2cc3fd-452f-4a67-bc6e-42bc038aae93"}, { new Terminator(OperatorType.Less), "491dd600-6fe1-4b4e-944c-44b15d27cddb"}, { new Terminator(OperatorType.LessEqual), "ea5f6ee8-d519-4361-8fcf-0543369675c7"}, { new Terminator(OperatorType.Greater), "99f43ff3-6ead-488e-91b6-ec4d6d34447d"}, { new Terminator(OperatorType.GreaterEqual), "d150fdc0-bc7a-4eb7-9fbc-d00ec9b297d1"}, { new NonTerminator(NonTerminatorType.AddOperator), "4cc0186a-c00d-4e29-baa3-741733f95a1f"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Expression))}, }, "d082188f-95b4-491e-9845-6333f9b77539") },
		{ "19275939-5968-41ff-a0e8-8accfd4f613e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "fcef5e6b-435e-4b7d-a136-b1bfcdb23ac6"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "19275939-5968-41ff-a0e8-8accfd4f613e") },
		{ "fa4afd19-9028-416d-8819-5013cebf7f6c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "fa4afd19-9028-416d-8819-5013cebf7f6c") },
		{ "c3446465-4a22-46ca-ad73-aa7d3ef043a3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "c3446465-4a22-46ca-ad73-aa7d3ef043a3") },
		{ "1092a928-59ea-4af5-8ac5-56dacd404605", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "1092a928-59ea-4af5-8ac5-56dacd404605") },
		{ "a3f9ee7c-7a4f-4424-b208-edcc3235c37c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "e72e1207-a1b7-4111-9ce9-925320e91ecc"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a3f9ee7c-7a4f-4424-b208-edcc3235c37c") },
		{ "a3885563-77b1-4418-9ffd-5d5b808d9458", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "4f7a1a58-b2a7-4174-ab53-080419660c7b"}, { new NonTerminator(NonTerminatorType.IdVarPart), "5553ab4e-b9f0-4760-98fb-389a0ba36ae4"}, { new Terminator(DelimiterType.LeftSquareBracket), "60001b9e-abdc-4582-a3b9-23c481e72528"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "a3885563-77b1-4418-9ffd-5d5b808d9458") },
		{ "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "b6b1a13e-923e-4c42-afa1-28628b4b784e"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4") },
		{ "e7187d2e-7304-4693-bd68-599577098ac6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "64210455-6270-46c9-891b-55adfdd813ee"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e7187d2e-7304-4693-bd68-599577098ac6") },
		{ "de4da83e-68c1-485a-aa8f-777d20322c89", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "5db32312-845d-4be5-864c-7d148de8d217"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "de4da83e-68c1-485a-aa8f-777d20322c89") },
		{ "2d453576-f044-48bf-a32d-014f99260626", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "aef0df0b-0c5c-46b2-9ac2-0591371367e2"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "2d453576-f044-48bf-a32d-014f99260626") },
		{ "8d4a4043-8902-4b16-9656-3e08535bcd6b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "8d4a4043-8902-4b16-9656-3e08535bcd6b") },
		{ "82459506-5865-4869-9748-1548327e336c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "82459506-5865-4869-9748-1548327e336c") },
		{ "94e0d4f8-3c2a-4375-b155-eafda749452b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "94e0d4f8-3c2a-4375-b155-eafda749452b") },
		{ "7e73c05f-d045-43d1-8a27-847dd891b9a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "3a33e423-968d-4e67-882d-cfafdaef33bf"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7e73c05f-d045-43d1-8a27-847dd891b9a5") },
		{ "be713fd7-c92e-42e0-bfd0-e069a60f4fcf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "45dce874-4f98-4d34-868d-999560cb823a"}, { new NonTerminator(NonTerminatorType.IdVarPart), "aa088f6c-47d8-4b50-98ec-0f2cb6381cad"}, { new Terminator(DelimiterType.LeftSquareBracket), "b6188a52-f83d-4a4c-8b30-d170792483c8"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf") },
		{ "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "fb25a229-d0ee-4487-bcd9-c5347743f1b7"}, { Terminator.NumberTerminator, "82459506-5865-4869-9748-1548327e336c"}, { new NonTerminator(NonTerminatorType.Variable), "94e0d4f8-3c2a-4375-b155-eafda749452b"}, { new Terminator(DelimiterType.LeftParenthesis), "7e73c05f-d045-43d1-8a27-847dd891b9a5"}, { Terminator.IdentifierTerminator, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf"}, { new Terminator(KeywordType.Not), "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f"}, { new Terminator(OperatorType.Minus), "f735189a-e838-4e6b-a3a6-19fa8a01364d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f") },
		{ "f735189a-e838-4e6b-a3a6-19fa8a01364d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "d6687345-217b-4a9c-a205-3d0e98764294"}, { Terminator.NumberTerminator, "82459506-5865-4869-9748-1548327e336c"}, { new NonTerminator(NonTerminatorType.Variable), "94e0d4f8-3c2a-4375-b155-eafda749452b"}, { new Terminator(DelimiterType.LeftParenthesis), "7e73c05f-d045-43d1-8a27-847dd891b9a5"}, { Terminator.IdentifierTerminator, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf"}, { new Terminator(KeywordType.Not), "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f"}, { new Terminator(OperatorType.Minus), "f735189a-e838-4e6b-a3a6-19fa8a01364d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f735189a-e838-4e6b-a3a6-19fa8a01364d") },
		{ "949cd87d-14c5-4642-9302-ca0bf1e13dbd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "88f40435-da28-4970-a1a5-87cd18d4b8c0"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "949cd87d-14c5-4642-9302-ca0bf1e13dbd") },
		{ "113ede1c-8d70-4d88-a9a3-578286dc8d47", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "113ede1c-8d70-4d88-a9a3-578286dc8d47") },
		{ "de56ce99-616d-4a00-9779-c36f636ed54e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "de56ce99-616d-4a00-9779-c36f636ed54e") },
		{ "75e68f1f-9f89-4756-b31e-31632f9bb9b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4474de22-e93d-4663-88e8-802dc4724785"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "75e68f1f-9f89-4756-b31e-31632f9bb9b8") },
		{ "57880f16-f23e-4043-8ebb-d3d7c7a7ea2c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "7e61a50b-b87c-4f9d-8471-4ab7d04940f1"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "57880f16-f23e-4043-8ebb-d3d7c7a7ea2c") },
		{ "341eb8f9-91a7-4d43-91bf-76624dc6f9e1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.CompoundStatement))}, }, "341eb8f9-91a7-4d43-91bf-76624dc6f9e1") },
		{ "7dc5dce4-78d8-4518-b196-4576d0237afe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.Semicolon), new ReduceInformation(6, new NonTerminator(NonTerminatorType.Type))}, }, "7dc5dce4-78d8-4518-b196-4576d0237afe") },
		{ "748e76e8-e3c3-46c5-8c77-daf70036acda", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { Terminator.NumberTerminator, "8734a66d-8fa9-4e7e-ba4c-217a37e76289"},}, new Dictionary<Terminator, ReduceInformation>{ }, "748e76e8-e3c3-46c5-8c77-daf70036acda") },
		{ "ee1eb23d-ad22-4acd-a847-54e6d30ad6ba", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "3f7121de-2734-4e7c-93c4-343c12452ee9"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "ee1eb23d-ad22-4acd-a847-54e6d30ad6ba") },
		{ "50925b30-cd16-47d2-8034-f787d2eefe23", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "50925b30-cd16-47d2-8034-f787d2eefe23") },
		{ "2ddfe3fb-3841-4d32-9977-76f8ee1dd9d1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "2ddfe3fb-3841-4d32-9977-76f8ee1dd9d1") },
		{ "dca691fe-380f-4761-b8b8-e16112947759", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "0cbbc74e-960c-4c14-ab94-476eb6e12ecc"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dca691fe-380f-4761-b8b8-e16112947759") },
		{ "67f79d7c-7642-4211-a456-dac1ea29ae7b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "1c50d325-7a00-4ab5-a4f5-b4c420f87428"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "67f79d7c-7642-4211-a456-dac1ea29ae7b") },
		{ "3774c848-d656-4b2b-895a-538ce52b81a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "73ec1778-6140-40b8-a6c6-31a479399b44"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "3774c848-d656-4b2b-895a-538ce52b81a5") },
		{ "3f9f12ab-92e6-41ab-ae33-2baad2eeca43", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "3f9f12ab-92e6-41ab-ae33-2baad2eeca43") },
		{ "7f0cd7ff-0090-4c8c-ba73-6cc2b0a843bd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "7f0cd7ff-0090-4c8c-ba73-6cc2b0a843bd") },
		{ "5e1ac291-b1e3-4d25-a4f1-84545e97cc53", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "7b84e792-d4fa-4cee-8642-4beb2b07c3fe"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5e1ac291-b1e3-4d25-a4f1-84545e97cc53") },
		{ "0cd0fa56-1f9e-4a4d-97aa-300f0d78a1da", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "7f734d5e-c221-483e-97c3-2acbcc08d6a5"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0cd0fa56-1f9e-4a4d-97aa-300f0d78a1da") },
		{ "07a4a59e-f4a5-4740-8cfb-1973f74a7d7f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "5bd4c184-2120-4a07-b969-1471a23e107a"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "07a4a59e-f4a5-4740-8cfb-1973f74a7d7f") },
		{ "3870ab24-1c1b-4cb9-bcf5-16d5772e0c04", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "3870ab24-1c1b-4cb9-bcf5-16d5772e0c04") },
		{ "69ff5341-5730-4c85-841e-202da5145b86", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "69ff5341-5730-4c85-841e-202da5145b86") },
		{ "2b2a99ad-249d-4a1c-986b-18aec7474217", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f014a7de-6b18-423c-bdc4-ca653178c498"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2b2a99ad-249d-4a1c-986b-18aec7474217") },
		{ "dff5f159-57ae-4ec6-800a-593e96505232", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "765d5d39-5160-41b2-9d11-190a30fd72e6"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "dff5f159-57ae-4ec6-800a-593e96505232") },
		{ "597d8f5a-fb3f-4431-a0df-ed5b93bd712e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "5d0080d6-4bd9-44c5-ac08-10c0f17760c5"}, { new NonTerminator(NonTerminatorType.Term), "8708e793-294c-4a9b-86f5-c2f11812b2e7"}, { new NonTerminator(NonTerminatorType.Factor), "67629330-88ae-43e6-8dab-dc82c687c59f"}, { Terminator.NumberTerminator, "b110c36e-97e6-47a2-8868-0d1064b9b031"}, { new NonTerminator(NonTerminatorType.Variable), "11f6a026-0e22-45e8-a357-13f0f2714392"}, { new Terminator(DelimiterType.LeftParenthesis), "4c113bb0-1a92-4d6f-bcdb-ebb974165774"}, { Terminator.IdentifierTerminator, "4c8c9091-6f56-41c2-a3a3-871eb493e534"}, { new Terminator(KeywordType.Not), "eea40151-e5f3-45dc-8db5-911ef5375059"}, { new Terminator(OperatorType.Minus), "f92adf13-0a01-45cf-b13b-00aa68e75f4d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "597d8f5a-fb3f-4431-a0df-ed5b93bd712e") },
		{ "53c766c4-cb3c-4808-87ba-ec83b70b7144", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "c01f3c9d-7a15-4c18-8648-fd44ec290445"}, { new NonTerminator(NonTerminatorType.Factor), "4ffc7b40-22bd-4d00-b236-1ecdc33d1c1c"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "53c766c4-cb3c-4808-87ba-ec83b70b7144") },
		{ "d2d8ac0a-cee5-44a1-88b2-a0c7ebffd9fa", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "d19a7283-91f2-4761-a987-1465c2225a2a"}, { Terminator.NumberTerminator, "f9d05b12-aa8a-418a-a630-145d75458c2c"}, { new NonTerminator(NonTerminatorType.Variable), "3a8f090b-7000-422e-a337-8a47e0dc41eb"}, { new Terminator(DelimiterType.LeftParenthesis), "0e578da4-76c7-41d0-a78a-0ce8c05adb66"}, { Terminator.IdentifierTerminator, "dad662a6-c5db-45e5-895c-7a67e47b112f"}, { new Terminator(KeywordType.Not), "320e1a39-5998-4a56-8921-c8342b376d6c"}, { new Terminator(OperatorType.Minus), "b3dc7239-be51-44f7-b53a-dfc19b1999e3"},}, new Dictionary<Terminator, ReduceInformation>{ }, "d2d8ac0a-cee5-44a1-88b2-a0c7ebffd9fa") },
		{ "0a0a04c9-c469-4ed4-b51a-ebb5379e4aff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4283e081-4983-455f-8ea5-702205c833f8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0a0a04c9-c469-4ed4-b51a-ebb5379e4aff") },
		{ "420603e3-e3fa-4260-91a2-6561c6b96611", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "00f4954c-ee60-46cb-a53e-073548d769a8"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "420603e3-e3fa-4260-91a2-6561c6b96611") },
		{ "753d5934-6a29-472d-b16d-b48b1fd9ac9f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "753d5934-6a29-472d-b16d-b48b1fd9ac9f") },
		{ "c0c1418b-c359-49ed-aca5-57cec34933ff", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "b2174268-ff95-4995-accf-685c11b3b1d0"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c0c1418b-c359-49ed-aca5-57cec34933ff") },
		{ "f7dad62f-ebe7-408c-a151-eb4e54c6e2c6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "f7dad62f-ebe7-408c-a151-eb4e54c6e2c6") },
		{ "b62a7a70-e2ba-4784-a59e-a770d6a614ec", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "b62a7a70-e2ba-4784-a59e-a770d6a614ec") },
		{ "e5b45ea3-1526-4f13-af6f-1a8f84c9a3ad", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.ProcedureCall))}, }, "e5b45ea3-1526-4f13-af6f-1a8f84c9a3ad") },
		{ "714345e7-8f29-4690-8a90-f5d56fa2c264", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ElsePart), "433860b2-e007-4942-9950-31edc0a0f6bb"}, { new Terminator(KeywordType.Else), "8b34a76d-d15f-4b4d-80ca-e86c8eba0559"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.ElsePart))}, }, "714345e7-8f29-4690-8a90-f5d56fa2c264") },
		{ "7a994450-b976-49e3-abfe-b93b77e25d77", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.To), "60d64153-1368-4026-b8a5-f8b7b8482057"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7a994450-b976-49e3-abfe-b93b77e25d77") },
		{ "8c321601-bb8b-49d9-acff-e02c1256ee75", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "8c321601-bb8b-49d9-acff-e02c1256ee75") },
		{ "9378afe3-f928-417f-8e16-bd369c2cc1be", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Then), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "9378afe3-f928-417f-8e16-bd369c2cc1be") },
		{ "b5035c5a-f649-4dd9-951f-aa10202bc183", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "b1549687-fbab-42f0-9580-f9d0feb4fe0a"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "b5035c5a-f649-4dd9-951f-aa10202bc183") },
		{ "fff24872-d37f-4365-9cef-dff7ca60914d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "fff24872-d37f-4365-9cef-dff7ca60914d") },
		{ "0ae6b8f8-60dc-4654-b374-a13c54b7fc63", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "0ae6b8f8-60dc-4654-b374-a13c54b7fc63") },
		{ "a786b8e5-e322-4fcf-b4f4-b0b353554608", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "cf450076-efe5-442b-b71b-892da0327666"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a786b8e5-e322-4fcf-b4f4-b0b353554608") },
		{ "9e93f16f-d7ca-439a-9ef0-ea91ffad7fa8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "2cad209f-a6a2-4d8b-aa77-ffb3952cd3b4"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "9e93f16f-d7ca-439a-9ef0-ea91ffad7fa8") },
		{ "94142f12-aeb9-4b28-ba6e-d4b2da3fe7d8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "8edb3054-c2a5-4751-8ca2-b94f3cbd44ac"}, { new NonTerminator(NonTerminatorType.Variable), "cbf78e0e-30be-444a-a889-49dada542a18"}, { Terminator.IdentifierTerminator, "b9d781e7-855d-47cf-9956-a824e41500d0"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "02741fe1-7c17-4f7b-bc5c-28b1e70f3a9d"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "74b98ed9-2c2c-4413-9b2d-d0a74162f661"}, { new Terminator(KeywordType.If), "1b980f94-6b9f-49a0-abd6-2c4f04f8eb17"}, { new Terminator(KeywordType.For), "1e574cb3-c9a8-48d8-b351-9172a92b168d"}, { new Terminator(KeywordType.Begin), "23caac79-74dd-413b-a5f5-f37380c3e5f9"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "94142f12-aeb9-4b28-ba6e-d4b2da3fe7d8") },
		{ "14274100-02ac-49b9-9ecf-56feb757d9b0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.SimpleExpression), "89dd361d-ed8a-4dc3-a5a8-ef2ab3593038"}, { new NonTerminator(NonTerminatorType.Term), "d0358e81-502b-46b8-9ce1-87f99947c281"}, { new NonTerminator(NonTerminatorType.Factor), "4cbabb07-6393-4e9e-92e2-946ded04fb12"}, { Terminator.NumberTerminator, "5d023232-434e-4984-b25d-a0957b9a8cdc"}, { new NonTerminator(NonTerminatorType.Variable), "59c8f508-22ae-4be1-acbf-a4b97ddbb79c"}, { new Terminator(DelimiterType.LeftParenthesis), "3638b138-3ecb-454b-9d12-edaa086f908e"}, { Terminator.IdentifierTerminator, "c05f8f79-7b68-435a-8770-bf0e81679415"}, { new Terminator(KeywordType.Not), "59eaf2bf-1978-4286-b1c6-687c7eb9c498"}, { new Terminator(OperatorType.Minus), "003bdd18-eab8-46c5-b572-3bed1781686d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "14274100-02ac-49b9-9ecf-56feb757d9b0") },
		{ "4cc0186a-c00d-4e29-baa3-741733f95a1f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "9f3c8529-2b30-492e-b547-5b7122dbb9f8"}, { new NonTerminator(NonTerminatorType.Factor), "fa4afd19-9028-416d-8819-5013cebf7f6c"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4cc0186a-c00d-4e29-baa3-741733f95a1f") },
		{ "fcef5e6b-435e-4b7d-a136-b1bfcdb23ac6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "307b5513-eeae-405f-b760-d121d5be2085"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "fcef5e6b-435e-4b7d-a136-b1bfcdb23ac6") },
		{ "e72e1207-a1b7-4111-9ce9-925320e91ecc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "1138e34d-a542-4384-aaed-29fca91938ef"},}, new Dictionary<Terminator, ReduceInformation>{ }, "e72e1207-a1b7-4111-9ce9-925320e91ecc") },
		{ "4f7a1a58-b2a7-4174-ab53-080419660c7b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8755db9e-4d2a-4337-81c6-d8a106daf972"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4f7a1a58-b2a7-4174-ab53-080419660c7b") },
		{ "5553ab4e-b9f0-4760-98fb-389a0ba36ae4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "5553ab4e-b9f0-4760-98fb-389a0ba36ae4") },
		{ "60001b9e-abdc-4582-a3b9-23c481e72528", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "b3da6250-4a03-4a41-9ea6-7c17f744dbf2"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "60001b9e-abdc-4582-a3b9-23c481e72528") },
		{ "b6b1a13e-923e-4c42-afa1-28628b4b784e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "b6b1a13e-923e-4c42-afa1-28628b4b784e") },
		{ "64210455-6270-46c9-891b-55adfdd813ee", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "64210455-6270-46c9-891b-55adfdd813ee") },
		{ "5db32312-845d-4be5-864c-7d148de8d217", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "95706919-d15e-44bd-a543-6d7e4da3befe"}, { new NonTerminator(NonTerminatorType.Factor), "8d4a4043-8902-4b16-9656-3e08535bcd6b"}, { Terminator.NumberTerminator, "82459506-5865-4869-9748-1548327e336c"}, { new NonTerminator(NonTerminatorType.Variable), "94e0d4f8-3c2a-4375-b155-eafda749452b"}, { new Terminator(DelimiterType.LeftParenthesis), "7e73c05f-d045-43d1-8a27-847dd891b9a5"}, { Terminator.IdentifierTerminator, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf"}, { new Terminator(KeywordType.Not), "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f"}, { new Terminator(OperatorType.Minus), "f735189a-e838-4e6b-a3a6-19fa8a01364d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "5db32312-845d-4be5-864c-7d148de8d217") },
		{ "aef0df0b-0c5c-46b2-9ac2-0591371367e2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "30f79251-7d01-4a34-b5e2-6a6f723bd98b"}, { Terminator.NumberTerminator, "82459506-5865-4869-9748-1548327e336c"}, { new NonTerminator(NonTerminatorType.Variable), "94e0d4f8-3c2a-4375-b155-eafda749452b"}, { new Terminator(DelimiterType.LeftParenthesis), "7e73c05f-d045-43d1-8a27-847dd891b9a5"}, { Terminator.IdentifierTerminator, "be713fd7-c92e-42e0-bfd0-e069a60f4fcf"}, { new Terminator(KeywordType.Not), "653eec1d-dbb2-43f8-9f1c-4ec9223ca88f"}, { new Terminator(OperatorType.Minus), "f735189a-e838-4e6b-a3a6-19fa8a01364d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "aef0df0b-0c5c-46b2-9ac2-0591371367e2") },
		{ "3a33e423-968d-4e67-882d-cfafdaef33bf", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "8a35d82a-4f29-4176-8ae9-b3594c65fdf9"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3a33e423-968d-4e67-882d-cfafdaef33bf") },
		{ "45dce874-4f98-4d34-868d-999560cb823a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "280791ce-7617-42b6-93db-bde9e22cffd4"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "45dce874-4f98-4d34-868d-999560cb823a") },
		{ "aa088f6c-47d8-4b50-98ec-0f2cb6381cad", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "aa088f6c-47d8-4b50-98ec-0f2cb6381cad") },
		{ "b6188a52-f83d-4a4c-8b30-d170792483c8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "51010bd9-bb55-4ca1-ad3c-8524e8a86084"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b6188a52-f83d-4a4c-8b30-d170792483c8") },
		{ "fb25a229-d0ee-4487-bcd9-c5347743f1b7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "fb25a229-d0ee-4487-bcd9-c5347743f1b7") },
		{ "d6687345-217b-4a9c-a205-3d0e98764294", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "d6687345-217b-4a9c-a205-3d0e98764294") },
		{ "4474de22-e93d-4663-88e8-802dc4724785", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "4474de22-e93d-4663-88e8-802dc4724785") },
		{ "7e61a50b-b87c-4f9d-8471-4ab7d04940f1", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "7e61a50b-b87c-4f9d-8471-4ab7d04940f1") },
		{ "8734a66d-8fa9-4e7e-ba4c-217a37e76289", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Period))}, }, "8734a66d-8fa9-4e7e-ba4c-217a37e76289") },
		{ "0cbbc74e-960c-4c14-ab94-476eb6e12ecc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "0cbbc74e-960c-4c14-ab94-476eb6e12ecc") },
		{ "1c50d325-7a00-4ab5-a4f5-b4c420f87428", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "1c50d325-7a00-4ab5-a4f5-b4c420f87428") },
		{ "7b84e792-d4fa-4cee-8642-4beb2b07c3fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "7b84e792-d4fa-4cee-8642-4beb2b07c3fe") },
		{ "7f734d5e-c221-483e-97c3-2acbcc08d6a5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightSquareBracket), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "7f734d5e-c221-483e-97c3-2acbcc08d6a5") },
		{ "f014a7de-6b18-423c-bdc4-ca653178c498", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "f014a7de-6b18-423c-bdc4-ca653178c498") },
		{ "765d5d39-5160-41b2-9d11-190a30fd72e6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Comma), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "765d5d39-5160-41b2-9d11-190a30fd72e6") },
		{ "5d0080d6-4bd9-44c5-ac08-10c0f17760c5", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "c75be6b2-600d-4359-89ab-b6cbc2e8bc07"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "5d0080d6-4bd9-44c5-ac08-10c0f17760c5") },
		{ "8708e793-294c-4a9b-86f5-c2f11812b2e7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "7fc774e9-4f9e-40be-8b7e-56aaaa2e020d"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "8708e793-294c-4a9b-86f5-c2f11812b2e7") },
		{ "67629330-88ae-43e6-8dab-dc82c687c59f", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "67629330-88ae-43e6-8dab-dc82c687c59f") },
		{ "b110c36e-97e6-47a2-8868-0d1064b9b031", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "b110c36e-97e6-47a2-8868-0d1064b9b031") },
		{ "11f6a026-0e22-45e8-a357-13f0f2714392", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "11f6a026-0e22-45e8-a357-13f0f2714392") },
		{ "4c113bb0-1a92-4d6f-bcdb-ebb974165774", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "2e459baa-9210-4e75-9468-60d4d4bb05f0"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "4c113bb0-1a92-4d6f-bcdb-ebb974165774") },
		{ "4c8c9091-6f56-41c2-a3a3-871eb493e534", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "8b865c66-6c43-4449-a08d-d9511433e2d3"}, { new NonTerminator(NonTerminatorType.IdVarPart), "77edc7f2-0e69-4ce9-8713-df4a45f4c4ca"}, { new Terminator(DelimiterType.LeftSquareBracket), "ace646b4-da3f-477a-9a9d-be73ebfdaa8e"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "4c8c9091-6f56-41c2-a3a3-871eb493e534") },
		{ "eea40151-e5f3-45dc-8db5-911ef5375059", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "5f6f67a2-829c-41b5-9ca8-4fb45419e3fe"}, { Terminator.NumberTerminator, "b110c36e-97e6-47a2-8868-0d1064b9b031"}, { new NonTerminator(NonTerminatorType.Variable), "11f6a026-0e22-45e8-a357-13f0f2714392"}, { new Terminator(DelimiterType.LeftParenthesis), "4c113bb0-1a92-4d6f-bcdb-ebb974165774"}, { Terminator.IdentifierTerminator, "4c8c9091-6f56-41c2-a3a3-871eb493e534"}, { new Terminator(KeywordType.Not), "eea40151-e5f3-45dc-8db5-911ef5375059"}, { new Terminator(OperatorType.Minus), "f92adf13-0a01-45cf-b13b-00aa68e75f4d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "eea40151-e5f3-45dc-8db5-911ef5375059") },
		{ "f92adf13-0a01-45cf-b13b-00aa68e75f4d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "95696be0-5068-4ff9-9372-fc9b0bd55ba2"}, { Terminator.NumberTerminator, "b110c36e-97e6-47a2-8868-0d1064b9b031"}, { new NonTerminator(NonTerminatorType.Variable), "11f6a026-0e22-45e8-a357-13f0f2714392"}, { new Terminator(DelimiterType.LeftParenthesis), "4c113bb0-1a92-4d6f-bcdb-ebb974165774"}, { Terminator.IdentifierTerminator, "4c8c9091-6f56-41c2-a3a3-871eb493e534"}, { new Terminator(KeywordType.Not), "eea40151-e5f3-45dc-8db5-911ef5375059"}, { new Terminator(OperatorType.Minus), "f92adf13-0a01-45cf-b13b-00aa68e75f4d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "f92adf13-0a01-45cf-b13b-00aa68e75f4d") },
		{ "c01f3c9d-7a15-4c18-8648-fd44ec290445", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "d2d8ac0a-cee5-44a1-88b2-a0c7ebffd9fa"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "c01f3c9d-7a15-4c18-8648-fd44ec290445") },
		{ "d19a7283-91f2-4761-a987-1465c2225a2a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "d19a7283-91f2-4761-a987-1465c2225a2a") },
		{ "4283e081-4983-455f-8ea5-702205c833f8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "4283e081-4983-455f-8ea5-702205c833f8") },
		{ "00f4954c-ee60-46cb-a53e-073548d769a8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "4801baf7-e670-49a5-98ce-46f9e99a9879"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "00f4954c-ee60-46cb-a53e-073548d769a8") },
		{ "b2174268-ff95-4995-accf-685c11b3b1d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "076b7d70-b77d-4b24-b027-5d388bb5c380"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b2174268-ff95-4995-accf-685c11b3b1d0") },
		{ "433860b2-e007-4942-9950-31edc0a0f6bb", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(5, new NonTerminator(NonTerminatorType.Statement))}, }, "433860b2-e007-4942-9950-31edc0a0f6bb") },
		{ "8b34a76d-d15f-4b4d-80ca-e86c8eba0559", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "633a4513-db7a-4fef-bcc4-ce084661b5ed"}, { new NonTerminator(NonTerminatorType.Variable), "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1"}, { Terminator.IdentifierTerminator, "0375bfdc-70d2-4173-820c-c00295879eb4"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "1166a74d-cd84-447a-884e-6e994b426865"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "35103497-0e41-4976-8eaf-a6784e27cad6"}, { new Terminator(KeywordType.If), "158f9f5f-b96c-400b-aea4-d420cac1e1f5"}, { new Terminator(KeywordType.For), "e5eae017-43f9-43a5-8cc6-b467d75a7d5d"}, { new Terminator(KeywordType.Begin), "5342eece-10e0-4678-9b11-0dfece0a51b4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "8b34a76d-d15f-4b4d-80ca-e86c8eba0559") },
		{ "60d64153-1368-4026-b8a5-f8b7b8482057", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "ba502afe-4699-4366-9985-e63122b32ddc"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "d082188f-95b4-491e-9845-6333f9b77539"}, { new NonTerminator(NonTerminatorType.Term), "19275939-5968-41ff-a0e8-8accfd4f613e"}, { new NonTerminator(NonTerminatorType.Factor), "fa4afd19-9028-416d-8819-5013cebf7f6c"}, { Terminator.NumberTerminator, "c3446465-4a22-46ca-ad73-aa7d3ef043a3"}, { new NonTerminator(NonTerminatorType.Variable), "1092a928-59ea-4af5-8ac5-56dacd404605"}, { new Terminator(DelimiterType.LeftParenthesis), "a3f9ee7c-7a4f-4424-b208-edcc3235c37c"}, { Terminator.IdentifierTerminator, "a3885563-77b1-4418-9ffd-5d5b808d9458"}, { new Terminator(KeywordType.Not), "71846de0-6ac0-42c6-8bb9-fd780a7bc8c4"}, { new Terminator(OperatorType.Minus), "e7187d2e-7304-4693-bd68-599577098ac6"},}, new Dictionary<Terminator, ReduceInformation>{ }, "60d64153-1368-4026-b8a5-f8b7b8482057") },
		{ "cf450076-efe5-442b-b71b-892da0327666", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "cf450076-efe5-442b-b71b-892da0327666") },
		{ "2cad209f-a6a2-4d8b-aa77-ffb3952cd3b4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(DelimiterType.RightParenthesis), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "2cad209f-a6a2-4d8b-aa77-ffb3952cd3b4") },
		{ "8edb3054-c2a5-4751-8ca2-b94f3cbd44ac", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "8edb3054-c2a5-4751-8ca2-b94f3cbd44ac") },
		{ "89dd361d-ed8a-4dc3-a5a8-ef2ab3593038", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.AddOperator), "0d890553-47d4-4c42-8b0c-c754d34b2d95"}, { new Terminator(OperatorType.Plus), "fed5f4ea-a71a-41ce-bbcc-17dbf4e137fd"}, { new Terminator(OperatorType.Minus), "ded9c168-151c-4d84-9ea8-b1b9c89f4b42"}, { new Terminator(KeywordType.Or), "74a6434c-3d29-45af-9711-0e57dd9a2b7c"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Expression))}, }, "89dd361d-ed8a-4dc3-a5a8-ef2ab3593038") },
		{ "d0358e81-502b-46b8-9ce1-87f99947c281", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a5a29f10-8370-4327-b26f-7c78f991cbed"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "d0358e81-502b-46b8-9ce1-87f99947c281") },
		{ "4cbabb07-6393-4e9e-92e2-946ded04fb12", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Term))}, }, "4cbabb07-6393-4e9e-92e2-946ded04fb12") },
		{ "5d023232-434e-4984-b25d-a0957b9a8cdc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "5d023232-434e-4984-b25d-a0957b9a8cdc") },
		{ "59c8f508-22ae-4be1-acbf-a4b97ddbb79c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(1, new NonTerminator(NonTerminatorType.Factor))}, }, "59c8f508-22ae-4be1-acbf-a4b97ddbb79c") },
		{ "3638b138-3ecb-454b-9d12-edaa086f908e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Expression), "28784544-e152-4bb7-9034-ca7bce08af4e"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "e6c7ce96-ad46-4a64-8e5e-c23656f3c9bc"}, { new NonTerminator(NonTerminatorType.Term), "061d0a90-dc23-4393-b750-6c90f01d0fa1"}, { new NonTerminator(NonTerminatorType.Factor), "a18f53ac-d7c5-49c4-bdd5-8483389d4c25"}, { Terminator.NumberTerminator, "94deaa4e-cb74-418b-b853-495567a0a29d"}, { new NonTerminator(NonTerminatorType.Variable), "c0a01468-a7ac-497b-bd1c-441c1a1f1e17"}, { new Terminator(DelimiterType.LeftParenthesis), "ddfc779c-0286-4ef9-af0b-17e404947c61"}, { Terminator.IdentifierTerminator, "838078c9-e208-461b-a70f-bef9dda8b800"}, { new Terminator(KeywordType.Not), "d850eaa2-f595-459f-8c6a-0009fb6fe711"}, { new Terminator(OperatorType.Minus), "0e05980a-6d1c-4861-bf49-081c9a58f840"},}, new Dictionary<Terminator, ReduceInformation>{ }, "3638b138-3ecb-454b-9d12-edaa086f908e") },
		{ "c05f8f79-7b68-435a-8770-bf0e81679415", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.LeftParenthesis), "b2eba269-f3eb-4f21-8421-3328d6c8d6cc"}, { new NonTerminator(NonTerminatorType.IdVarPart), "f820823a-1c86-4270-9d61-420a9953d824"}, { new Terminator(DelimiterType.LeftSquareBracket), "2b71ba44-375a-40ef-871a-681e73621cc6"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(0, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "c05f8f79-7b68-435a-8770-bf0e81679415") },
		{ "59eaf2bf-1978-4286-b1c6-687c7eb9c498", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "649470b0-6753-49c7-8d00-2daf704097fd"}, { Terminator.NumberTerminator, "5d023232-434e-4984-b25d-a0957b9a8cdc"}, { new NonTerminator(NonTerminatorType.Variable), "59c8f508-22ae-4be1-acbf-a4b97ddbb79c"}, { new Terminator(DelimiterType.LeftParenthesis), "3638b138-3ecb-454b-9d12-edaa086f908e"}, { Terminator.IdentifierTerminator, "c05f8f79-7b68-435a-8770-bf0e81679415"}, { new Terminator(KeywordType.Not), "59eaf2bf-1978-4286-b1c6-687c7eb9c498"}, { new Terminator(OperatorType.Minus), "003bdd18-eab8-46c5-b572-3bed1781686d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "59eaf2bf-1978-4286-b1c6-687c7eb9c498") },
		{ "003bdd18-eab8-46c5-b572-3bed1781686d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "7b540ff4-be4f-4d67-a5fb-0f0b2d494793"}, { Terminator.NumberTerminator, "5d023232-434e-4984-b25d-a0957b9a8cdc"}, { new NonTerminator(NonTerminatorType.Variable), "59c8f508-22ae-4be1-acbf-a4b97ddbb79c"}, { new Terminator(DelimiterType.LeftParenthesis), "3638b138-3ecb-454b-9d12-edaa086f908e"}, { Terminator.IdentifierTerminator, "c05f8f79-7b68-435a-8770-bf0e81679415"}, { new Terminator(KeywordType.Not), "59eaf2bf-1978-4286-b1c6-687c7eb9c498"}, { new Terminator(OperatorType.Minus), "003bdd18-eab8-46c5-b572-3bed1781686d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "003bdd18-eab8-46c5-b572-3bed1781686d") },
		{ "9f3c8529-2b30-492e-b547-5b7122dbb9f8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "fcef5e6b-435e-4b7d-a136-b1bfcdb23ac6"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "9f3c8529-2b30-492e-b547-5b7122dbb9f8") },
		{ "307b5513-eeae-405f-b760-d121d5be2085", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "307b5513-eeae-405f-b760-d121d5be2085") },
		{ "1138e34d-a542-4384-aaed-29fca91938ef", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "1138e34d-a542-4384-aaed-29fca91938ef") },
		{ "8755db9e-4d2a-4337-81c6-d8a106daf972", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "d78b8005-b80d-42b0-b17e-e5cda713dea7"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8755db9e-4d2a-4337-81c6-d8a106daf972") },
		{ "b3da6250-4a03-4a41-9ea6-7c17f744dbf2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "8d4f17ff-47ac-49a9-be50-bf758fbfaa88"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b3da6250-4a03-4a41-9ea6-7c17f744dbf2") },
		{ "95706919-d15e-44bd-a543-6d7e4da3befe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "aef0df0b-0c5c-46b2-9ac2-0591371367e2"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "95706919-d15e-44bd-a543-6d7e4da3befe") },
		{ "30f79251-7d01-4a34-b5e2-6a6f723bd98b", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "30f79251-7d01-4a34-b5e2-6a6f723bd98b") },
		{ "8a35d82a-4f29-4176-8ae9-b3594c65fdf9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "8a35d82a-4f29-4176-8ae9-b3594c65fdf9") },
		{ "280791ce-7617-42b6-93db-bde9e22cffd4", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "3a13b017-d81d-4b65-9261-c45f92038fa9"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "280791ce-7617-42b6-93db-bde9e22cffd4") },
		{ "51010bd9-bb55-4ca1-ad3c-8524e8a86084", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "5568a49b-94e7-427d-b168-9e44b683e12e"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "51010bd9-bb55-4ca1-ad3c-8524e8a86084") },
		{ "c75be6b2-600d-4359-89ab-b6cbc2e8bc07", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "39e0cccd-0674-4b5d-a2d3-b4f5556a52c3"}, { new NonTerminator(NonTerminatorType.Factor), "67629330-88ae-43e6-8dab-dc82c687c59f"}, { Terminator.NumberTerminator, "b110c36e-97e6-47a2-8868-0d1064b9b031"}, { new NonTerminator(NonTerminatorType.Variable), "11f6a026-0e22-45e8-a357-13f0f2714392"}, { new Terminator(DelimiterType.LeftParenthesis), "4c113bb0-1a92-4d6f-bcdb-ebb974165774"}, { Terminator.IdentifierTerminator, "4c8c9091-6f56-41c2-a3a3-871eb493e534"}, { new Terminator(KeywordType.Not), "eea40151-e5f3-45dc-8db5-911ef5375059"}, { new Terminator(OperatorType.Minus), "f92adf13-0a01-45cf-b13b-00aa68e75f4d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "c75be6b2-600d-4359-89ab-b6cbc2e8bc07") },
		{ "7fc774e9-4f9e-40be-8b7e-56aaaa2e020d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "11deacd2-0e9e-496a-ae0a-41e116cc13f0"}, { Terminator.NumberTerminator, "b110c36e-97e6-47a2-8868-0d1064b9b031"}, { new NonTerminator(NonTerminatorType.Variable), "11f6a026-0e22-45e8-a357-13f0f2714392"}, { new Terminator(DelimiterType.LeftParenthesis), "4c113bb0-1a92-4d6f-bcdb-ebb974165774"}, { Terminator.IdentifierTerminator, "4c8c9091-6f56-41c2-a3a3-871eb493e534"}, { new Terminator(KeywordType.Not), "eea40151-e5f3-45dc-8db5-911ef5375059"}, { new Terminator(OperatorType.Minus), "f92adf13-0a01-45cf-b13b-00aa68e75f4d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "7fc774e9-4f9e-40be-8b7e-56aaaa2e020d") },
		{ "2e459baa-9210-4e75-9468-60d4d4bb05f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "57229805-bbe0-4a2b-a596-4fee4cdbbc09"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2e459baa-9210-4e75-9468-60d4d4bb05f0") },
		{ "8b865c66-6c43-4449-a08d-d9511433e2d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "1d1aa6ea-f579-4c68-a9ae-d2e60d79ddd8"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8b865c66-6c43-4449-a08d-d9511433e2d3") },
		{ "77edc7f2-0e69-4ce9-8713-df4a45f4c4ca", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "77edc7f2-0e69-4ce9-8713-df4a45f4c4ca") },
		{ "ace646b4-da3f-477a-9a9d-be73ebfdaa8e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "06bd2695-c234-452d-bd55-45e2e7f3a4c3"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ace646b4-da3f-477a-9a9d-be73ebfdaa8e") },
		{ "5f6f67a2-829c-41b5-9ca8-4fb45419e3fe", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "5f6f67a2-829c-41b5-9ca8-4fb45419e3fe") },
		{ "95696be0-5068-4ff9-9372-fc9b0bd55ba2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "95696be0-5068-4ff9-9372-fc9b0bd55ba2") },
		{ "4801baf7-e670-49a5-98ce-46f9e99a9879", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "4801baf7-e670-49a5-98ce-46f9e99a9879") },
		{ "076b7d70-b77d-4b24-b027-5d388bb5c380", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "076b7d70-b77d-4b24-b027-5d388bb5c380") },
		{ "633a4513-db7a-4fef-bcc4-ce084661b5ed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(KeywordType.Else), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(2, new NonTerminator(NonTerminatorType.ElsePart))}, }, "633a4513-db7a-4fef-bcc4-ce084661b5ed") },
		{ "ba502afe-4699-4366-9985-e63122b32ddc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(KeywordType.Do), "18141fa2-651e-4499-95fb-f3ff214acc5c"},}, new Dictionary<Terminator, ReduceInformation>{ }, "ba502afe-4699-4366-9985-e63122b32ddc") },
		{ "0d890553-47d4-4c42-8b0c-c754d34b2d95", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Term), "eb59b00e-f251-4d9b-bd68-f799596a86d3"}, { new NonTerminator(NonTerminatorType.Factor), "4cbabb07-6393-4e9e-92e2-946ded04fb12"}, { Terminator.NumberTerminator, "5d023232-434e-4984-b25d-a0957b9a8cdc"}, { new NonTerminator(NonTerminatorType.Variable), "59c8f508-22ae-4be1-acbf-a4b97ddbb79c"}, { new Terminator(DelimiterType.LeftParenthesis), "3638b138-3ecb-454b-9d12-edaa086f908e"}, { Terminator.IdentifierTerminator, "c05f8f79-7b68-435a-8770-bf0e81679415"}, { new Terminator(KeywordType.Not), "59eaf2bf-1978-4286-b1c6-687c7eb9c498"}, { new Terminator(OperatorType.Minus), "003bdd18-eab8-46c5-b572-3bed1781686d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "0d890553-47d4-4c42-8b0c-c754d34b2d95") },
		{ "a5a29f10-8370-4327-b26f-7c78f991cbed", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Factor), "7c0ce2f3-e44f-43b9-86f3-6268ccfce401"}, { Terminator.NumberTerminator, "5d023232-434e-4984-b25d-a0957b9a8cdc"}, { new NonTerminator(NonTerminatorType.Variable), "59c8f508-22ae-4be1-acbf-a4b97ddbb79c"}, { new Terminator(DelimiterType.LeftParenthesis), "3638b138-3ecb-454b-9d12-edaa086f908e"}, { Terminator.IdentifierTerminator, "c05f8f79-7b68-435a-8770-bf0e81679415"}, { new Terminator(KeywordType.Not), "59eaf2bf-1978-4286-b1c6-687c7eb9c498"}, { new Terminator(OperatorType.Minus), "003bdd18-eab8-46c5-b572-3bed1781686d"},}, new Dictionary<Terminator, ReduceInformation>{ }, "a5a29f10-8370-4327-b26f-7c78f991cbed") },
		{ "28784544-e152-4bb7-9034-ca7bce08af4e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "a451933a-bc3c-41d4-82bf-553cff89fd63"},}, new Dictionary<Terminator, ReduceInformation>{ }, "28784544-e152-4bb7-9034-ca7bce08af4e") },
		{ "b2eba269-f3eb-4f21-8421-3328d6c8d6cc", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "8a21ff41-2b69-4912-ad3a-eb2528f88d8a"}, { new NonTerminator(NonTerminatorType.Expression), "42cec062-e3c3-4677-824f-cdf54a69a96d"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "7e190023-6e73-4a84-a4f5-c0e7ccbdc4bc"}, { new NonTerminator(NonTerminatorType.Term), "d45f1af1-d596-4ff3-ba54-bf0a96485caa"}, { new NonTerminator(NonTerminatorType.Factor), "84b00276-3b69-49e5-8f8e-57d37861e592"}, { Terminator.NumberTerminator, "9b4dbc9e-3a03-4126-9252-97d5b0bd1486"}, { new NonTerminator(NonTerminatorType.Variable), "50bdb82b-22d8-40ab-90ed-a0cb47b37e31"}, { new Terminator(DelimiterType.LeftParenthesis), "88c807ca-f1ff-40f4-9ca9-f58790021817"}, { Terminator.IdentifierTerminator, "349b78b5-cf5e-45b6-82e3-c4de09db7f9c"}, { new Terminator(KeywordType.Not), "e7c7a9b9-fa5e-4fbc-9afa-0f90c1386f99"}, { new Terminator(OperatorType.Minus), "20009023-7acd-4763-8234-1127840c6bb8"},}, new Dictionary<Terminator, ReduceInformation>{ }, "b2eba269-f3eb-4f21-8421-3328d6c8d6cc") },
		{ "f820823a-1c86-4270-9d61-420a9953d824", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Variable))}, }, "f820823a-1c86-4270-9d61-420a9953d824") },
		{ "2b71ba44-375a-40ef-871a-681e73621cc6", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.ExpressionList), "52b869dc-468a-4afb-94d3-395d2fe7b7a2"}, { new NonTerminator(NonTerminatorType.Expression), "fed37968-d822-446a-ac23-a1c709636058"}, { new NonTerminator(NonTerminatorType.SimpleExpression), "8674abec-86a6-45fb-bbf9-7212155c0a45"}, { new NonTerminator(NonTerminatorType.Term), "24beb9a9-8c5c-49a1-9dff-f50d06306e7e"}, { new NonTerminator(NonTerminatorType.Factor), "b7e313c6-3274-404b-b681-fea2f0476fe9"}, { Terminator.NumberTerminator, "a90cc1fe-fe7b-433d-8e5c-9e14989b1063"}, { new NonTerminator(NonTerminatorType.Variable), "b6f34cf6-843f-4381-9313-c048737ee827"}, { new Terminator(DelimiterType.LeftParenthesis), "b47fbc41-e16a-4357-bb83-24de77644b36"}, { Terminator.IdentifierTerminator, "1713c6c4-f2c4-4047-bfb9-9965cb913903"}, { new Terminator(KeywordType.Not), "f3b32425-ac50-4033-86e2-f3088f94ac5a"}, { new Terminator(OperatorType.Minus), "3a223695-8674-4413-b39f-d5c9812ff660"},}, new Dictionary<Terminator, ReduceInformation>{ }, "2b71ba44-375a-40ef-871a-681e73621cc6") },
		{ "649470b0-6753-49c7-8d00-2daf704097fd", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "649470b0-6753-49c7-8d00-2daf704097fd") },
		{ "7b540ff4-be4f-4d67-a5fb-0f0b2d494793", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(2, new NonTerminator(NonTerminatorType.Factor))}, }, "7b540ff4-be4f-4d67-a5fb-0f0b2d494793") },
		{ "d78b8005-b80d-42b0-b17e-e5cda713dea7", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Equal), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Less), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Greater), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "d78b8005-b80d-42b0-b17e-e5cda713dea7") },
		{ "8d4f17ff-47ac-49a9-be50-bf758fbfaa88", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Equal), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.NotEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Less), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.LessEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Greater), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.GreaterEqual), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "8d4f17ff-47ac-49a9-be50-bf758fbfaa88") },
		{ "3a13b017-d81d-4b65-9261-c45f92038fa9", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "3a13b017-d81d-4b65-9261-c45f92038fa9") },
		{ "5568a49b-94e7-427d-b168-9e44b683e12e", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.To), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "5568a49b-94e7-427d-b168-9e44b683e12e") },
		{ "39e0cccd-0674-4b5d-a2d3-b4f5556a52c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "7fc774e9-4f9e-40be-8b7e-56aaaa2e020d"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "39e0cccd-0674-4b5d-a2d3-b4f5556a52c3") },
		{ "11deacd2-0e9e-496a-ae0a-41e116cc13f0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "11deacd2-0e9e-496a-ae0a-41e116cc13f0") },
		{ "57229805-bbe0-4a2b-a596-4fee4cdbbc09", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "57229805-bbe0-4a2b-a596-4fee4cdbbc09") },
		{ "1d1aa6ea-f579-4c68-a9ae-d2e60d79ddd8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "f7cd148a-d038-443b-ada7-238f6bdc494d"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "1d1aa6ea-f579-4c68-a9ae-d2e60d79ddd8") },
		{ "06bd2695-c234-452d-bd55-45e2e7f3a4c3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "95efada4-f56b-4cc0-a018-99a5e03d0f23"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "06bd2695-c234-452d-bd55-45e2e7f3a4c3") },
		{ "18141fa2-651e-4499-95fb-f3ff214acc5c", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.Statement), "a2546be5-797b-4831-b275-7861415b04d0"}, { new NonTerminator(NonTerminatorType.Variable), "7b440a1d-5b4e-4938-a98b-0acd95b4a7a1"}, { Terminator.IdentifierTerminator, "0375bfdc-70d2-4173-820c-c00295879eb4"}, { new NonTerminator(NonTerminatorType.ProcedureCall), "1166a74d-cd84-447a-884e-6e994b426865"}, { new NonTerminator(NonTerminatorType.CompoundStatement), "35103497-0e41-4976-8eaf-a6784e27cad6"}, { new Terminator(KeywordType.If), "158f9f5f-b96c-400b-aea4-d420cac1e1f5"}, { new Terminator(KeywordType.For), "e5eae017-43f9-43a5-8cc6-b467d75a7d5d"}, { new Terminator(KeywordType.Begin), "5342eece-10e0-4678-9b11-0dfece0a51b4"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(0, new NonTerminator(NonTerminatorType.Statement))}, }, "18141fa2-651e-4499-95fb-f3ff214acc5c") },
		{ "eb59b00e-f251-4d9b-bd68-f799596a86d3", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new NonTerminator(NonTerminatorType.MultiplyOperator), "a5a29f10-8370-4327-b26f-7c78f991cbed"}, { new Terminator(OperatorType.Multiply), "0eca1a66-008d-4c96-b177-2bfbaee76e2c"}, { new Terminator(OperatorType.Divide), "ad4dc115-e8ac-460d-a3f3-3f99aeb88803"}, { new Terminator(KeywordType.Divide), "820ae9cc-7b03-4a73-a7db-487c6452a91e"}, { new Terminator(KeywordType.Mod), "0d2f7d93-b3fc-47cb-8c5f-a5324086dfb6"}, { new Terminator(KeywordType.And), "6551cb6c-d1cb-41e4-9850-08ac8a227d44"},}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.SimpleExpression))}, }, "eb59b00e-f251-4d9b-bd68-f799596a86d3") },
		{ "7c0ce2f3-e44f-43b9-86f3-6268ccfce401", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Term))}, }, "7c0ce2f3-e44f-43b9-86f3-6268ccfce401") },
		{ "a451933a-bc3c-41d4-82bf-553cff89fd63", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.Factor))}, }, "a451933a-bc3c-41d4-82bf-553cff89fd63") },
		{ "8a21ff41-2b69-4912-ad3a-eb2528f88d8a", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightParenthesis), "c59d58f0-2587-4df5-8a21-493520e13f85"}, { new Terminator(DelimiterType.Comma), "f9bc7017-c0f6-491e-9363-4a7bd45a0383"},}, new Dictionary<Terminator, ReduceInformation>{ }, "8a21ff41-2b69-4912-ad3a-eb2528f88d8a") },
		{ "52b869dc-468a-4afb-94d3-395d2fe7b7a2", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{ { new Terminator(DelimiterType.RightSquareBracket), "19bd03a0-de71-443e-a556-6a93b29926b8"}, { new Terminator(DelimiterType.Comma), "22b74200-b351-4d56-b227-baa12d161065"},}, new Dictionary<Terminator, ReduceInformation>{ }, "52b869dc-468a-4afb-94d3-395d2fe7b7a2") },
		{ "f7cd148a-d038-443b-ada7-238f6bdc494d", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Else), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "f7cd148a-d038-443b-ada7-238f6bdc494d") },
		{ "95efada4-f56b-4cc0-a018-99a5e03d0f23", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Else), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "95efada4-f56b-4cc0-a018-99a5e03d0f23") },
		{ "a2546be5-797b-4831-b275-7861415b04d0", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.End), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(KeywordType.Else), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, { new Terminator(DelimiterType.Semicolon), new ReduceInformation(8, new NonTerminator(NonTerminatorType.Statement))}, }, "a2546be5-797b-4831-b275-7861415b04d0") },
		{ "c59d58f0-2587-4df5-8a21-493520e13f85", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Divide), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Mod), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.And), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Plus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(OperatorType.Minus), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, { new Terminator(KeywordType.Or), new ReduceInformation(4, new NonTerminator(NonTerminatorType.Factor))}, }, "c59d58f0-2587-4df5-8a21-493520e13f85") },
		{ "19bd03a0-de71-443e-a556-6a93b29926b8", new GeneratedTransformer(new Dictionary<TerminatorBase, string>{}, new Dictionary<Terminator, ReduceInformation>{ { new Terminator(KeywordType.Do), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Multiply), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Divide), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Mod), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.And), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Plus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(OperatorType.Minus), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, { new Terminator(KeywordType.Or), new ReduceInformation(3, new NonTerminator(NonTerminatorType.IdVarPart))}, }, "19bd03a0-de71-443e-a556-6a93b29926b8") },
	};

    private GeneratedGrammarParser()
    {
        foreach(GeneratedTransformer transformer in s_transformers.Values)
        {
            transformer.ConstructShiftTable(s_transformers);
        }
    }

    private static GeneratedGrammarParser s_instance = new GeneratedGrammarParser();

    public static GeneratedGrammarParser Instance => s_instance;

	public ITransformer BeginTransformer => s_transformers["28c8b345-5ba6-40c1-93f1-1e6c1fa1400b"];
	public NonTerminator Begin => new NonTerminator(NonTerminatorType.StartNonTerminator);
}
